@@ -18,16 +18,15 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Header: /ufs/repository/magic/calma/CalmaRdcl.c,v 1.4 2001/07/23 17:49:49 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/calma/CalmaRdcl.c,v 1.4 2005/05/31 21:41:24 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
 #include <string.h>
 #include <sys/types.h>
-
 #include <netinet/in.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/utils.h"
@@ -35,14 +34,14 @@ static char rcsid[] = "$Header: /ufs/repository/magic/calma/CalmaRdcl.c,v 1.4 20
 #include "database/database.h"
 #include "database/databaseInt.h"
 #include "utils/malloc.h"
-#include "tech/tech.h"
+#include "utils/tech.h"
 #include "cif/cif.h"
 #include "cif/CIFint.h"
 #include "cif/CIFread.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "textio/textio.h"
 #include "calma/calmaInt.h"
 #include "calma/calma.h"
@@ -64,6 +63,125 @@ typedef struct {
     Transform *trans;
 } GDSCopyRec;
 
+/* Added by NP 8/11/04 */
+
+/*
+ * ----------------------------------------------------------------------------
+ *
+ * calmaSetPosition --
+ *
+ *  This routine sets the file pointer calmaInputFile to the start
+ *  of the CellDefinition "sname". It starts the search from the
+ *  current position and looks forward to find the Cell Definition
+ *  named "sname".
+ *
+ * Results:
+ *	Current position of file pointer before it jumps to the
+ *	definition of cell "sname" (if it exists, otherwise, returns
+ *	end-of-file).
+ *
+ * Side Effects:
+ *	The file position is set to the definition of cell "sname". If
+ *	"sname" does not exist in the GDS stream file, the pointer is
+ *	set to the end of the file.
+ *
+ * ----------------------------------------------------------------------------
+ */
+
+off_t
+calmaSetPosition(sname)
+    char *sname;
+{
+    off_t originalPos = 0, currentPos = 0;
+    int nbytes, rtype;
+    char *strname = NULL;
+    int strRecSize = 0;
+
+    originalPos = ftell(calmaInputFile);
+
+    while (feof(calmaInputFile) == 0)
+    {
+        do
+        {
+             READRH(nbytes, rtype);      /* Read header	*/
+             if (nbytes <= 0) goto complete;
+
+             /* Skip no of bytes in record header until
+              * we reach to next structure record.
+              */
+             fseek(calmaInputFile, nbytes - CALMAHEADERLENGTH, SEEK_CUR);
+        } while (rtype != CALMA_BGNSTR);
+
+        calmaReadStringRecord(CALMA_STRNAME, &strname);
+        if ((strcmp(sname, strname)) == 0)
+        {
+             /* If name if structure matches with given name,
+              * we got that Cell Defination. Set position of
+              * file to start of that structure.
+              */
+             strRecSize = strlen(strname);
+             if (strRecSize & 01) strRecSize++;
+             fseek(calmaInputFile, -(nbytes + strRecSize + CALMAHEADERLENGTH),
+				SEEK_CUR);
+             break;
+        }
+     }
+
+complete:
+     /* Done with strname */
+     if (strname != NULL) freeMagic(strname);
+     return originalPos;
+}
+
+/* Added by NP 8/11/04 */
+
+/*
+ * ----------------------------------------------------------------------------
+ *
+ * calmaNextCell --
+ *
+ *   This routine sets the file pointer to next Cell Definition
+ *   in the GDS stream. It goes only in the forward direction
+ *   from the current position of the file pointer.
+ *
+ * Results:
+ *	None.
+ *
+ * Side Effects:
+ *	File pointer set to start of next Cell definition.
+ *
+ * ----------------------------------------------------------------------------
+ */
+
+void
+calmaNextCell()
+{
+    int nbytes, rtype;
+
+    if (feof(calmaInputFile) == 0)
+    {
+        do
+        {
+             READRH(nbytes, rtype);      /* Read header */
+             if (nbytes <= 0)
+             {
+                /* We have reached the end of the file.  There are no
+		 * more cell definitions remaining to read.
+                 * Set file pointer to CALMA_ENDLIB record.
+		 */
+                fseek(calmaInputFile, -(CALMAHEADERLENGTH), SEEK_END);
+                return;
+             }
+
+             /* Skip no. of bytes in record header to reach the next
+	      * structure record.
+              */
+             fseek(calmaInputFile, nbytes - CALMAHEADERLENGTH, SEEK_CUR);
+        } while(rtype != CALMA_BGNSTR);
+        fseek(calmaInputFile, -nbytes, SEEK_CUR);
+    }
+}
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -78,7 +196,7 @@ typedef struct {
  * CIF cell, so that it can be destroyed after read-in and flattening.
  *
  * Results:
- *	None.
+ *	Pointer to the plane structure created to hold the GDS data.
  *
  * Side Effects:
  *	Swaps the planes of cifReadCellDef with cifCurReadPlanes.
@@ -86,7 +204,7 @@ typedef struct {
  * ----------------------------------------------------------------------------
  */
 
-void
+Plane **
 calmaExact()
 {
     int pNum;
@@ -114,12 +232,12 @@ calmaExact()
 	else
 	    parray[pNum] = NULL;
     }
-    cifReadCellDef->cd_client = (ClientData)parray;
-    cifReadCellDef->cd_flags |= CDFLATGDS;
 
     /* Clear out the current paint planes for the next cell */
     for (pNum = 0; pNum < MAXCIFRLAYERS; pNum++)
 	DBClearPaintPlane(cifCurReadPlanes[pNum]);
+
+    return parray;
 }
 
 
@@ -156,9 +274,7 @@ calmaParseStructure(filename)
     int mfactor;
     off_t filepos;
     bool was_called;
-
-    if (CalmaReadOnly)
-	filepos = ftell(calmaInputFile);
+    CellDef *def;
 
     /* Make sure this is a structure; if not, let the caller know we're done */
     PEEKRH(nbytes, rtype);
@@ -170,18 +286,30 @@ calmaParseStructure(filename)
     if (!calmaReadStringRecord(CALMA_STRNAME, &strname)) goto syntaxerror;
     TxPrintf("Reading \"%s\".\n", strname);
 
+    if (CalmaReadOnly)
+	filepos = ftell(calmaInputFile);
+
     /* Set up the cell definition */
     he = HashFind(&calmaDefInitHash, strname);
-    if (HashGetValue(he))
+    if ((def = (CellDef *)HashGetValue(he)) != NULL)
     {
-	for (suffix = 1; HashGetValue(he) != NULL; suffix++)
+	if (def->cd_flags & CDPROCESSEDGDS)
 	{
-	    (void) sprintf(newname, "%s_%d", strname, suffix);
-	    he = HashFind(&calmaDefInitHash, newname);
+	    /* If cell definition was marked as processed, then skip */
+	    calmaNextCell();
+	    return TRUE;
+	}
+	else
+	{
+	    for (suffix = 1; HashGetValue(he) != NULL; suffix++)
+	    {
+		(void) sprintf(newname, "%s_%d", strname, suffix);
+		he = HashFind(&calmaDefInitHash, newname);
+	    }
+	    calmaReadError("Cell \"%s\" was already defined in this file.\n", strname);
+	    calmaReadError("Giving this cell a new name: %s\n", newname);
+	    strncpy(strname, newname, CALMANAMELENGTH*2);
 	}
-	calmaReadError("Cell \"%s\" was already defined in this file.\n", strname);
-	calmaReadError("Giving this cell a new name: %s\n", newname);
-	(void) strncpy(strname, newname, CALMANAMELENGTH*2);
     }
     cifReadCellDef = calmaFindCell(strname, &was_called);
     DBCellClearDef(cifReadCellDef);
@@ -192,6 +320,10 @@ calmaParseStructure(filename)
     /* Done with strname */
     if (strname != NULL) freeMagic(strname);
 
+    /* For read-only cells, set flag in def */
+    if (CalmaReadOnly)
+	cifReadCellDef->cd_flags |= CDVENDORGDS;
+
     /* Skip CALMA_STRCLASS or CALMA_STRTYPE */
     calmaSkipSet(structs);
 
@@ -231,7 +363,7 @@ calmaParseStructure(filename)
 	char *fpcopy = (char *)mallocMagic(20);
 	char *fncopy = StrDup(NULL, filename);
 	sprintf(fpcopy, "%d", filepos);
-	DBPropPut(cifReadCellDef, "GDS_BEGIN", (ClientData)fpcopy);
+	DBPropPut(cifReadCellDef, "GDS_START", (ClientData)fpcopy);
 
 	fpcopy = (char *)mallocMagic(20);
 	filepos = ftell(calmaInputFile);
@@ -239,7 +371,10 @@ calmaParseStructure(filename)
 	DBPropPut(cifReadCellDef, "GDS_END", (ClientData)fpcopy);
 
 	DBPropPut(cifReadCellDef, "GDS_FILE", (ClientData)fncopy);
-	cifReadCellDef->cd_flags |= CDNOEDIT;
+
+	/* Do not lock the cell, or else we can't save the	*/
+	/* magic cell with its GDS pointers to disk. . .	*/
+	/* cifReadCellDef->cd_flags |= CDNOEDIT; */
     }
 
     /*
@@ -250,7 +385,8 @@ calmaParseStructure(filename)
     if (CalmaFlattenUses && (!was_called) && (npaths < 10) && (nsrefs == 0))
     {
 	TxPrintf("Flattening cell %s\n", cifReadCellDef->cd_name);
-	calmaExact();
+	cifReadCellDef->cd_client = (ClientData) calmaExact();
+	cifReadCellDef->cd_flags |= CDFLATGDS;
     }
     else
     {
@@ -266,9 +402,12 @@ calmaParseStructure(filename)
 	      (cifCurReadStyle->crs_flags & CRF_NO_RECONNECT_LABELS) ? 1 : 0);
     DBReComputeBbox(cifReadCellDef);
 
-    /* Don't bother to register with DRC if we're going to delete the cell */
+    /* Don't bother to register with DRC if we're going to delete the	*/
+    /* cell, or if the cell is read-only.				*/
+
     if (!CalmaFlattenUses || (npaths >= 10) || (nsrefs != 0))
-	DRCCheckThis(cifReadCellDef, TT_CHECKPAINT, &cifReadCellDef->cd_bbox);
+	if (!CalmaReadOnly)
+	    DRCCheckThis(cifReadCellDef, TT_CHECKPAINT, &cifReadCellDef->cd_bbox);
 
     DBWAreaChanged(cifReadCellDef, &cifReadCellDef->cd_bbox,
 	DBW_ALLWINDOWS, &DBAllButSpaceBits);
@@ -280,6 +419,7 @@ calmaParseStructure(filename)
      * unique.
      */
     DBGenerateUniqueIds(cifReadCellDef, FALSE);
+    cifReadCellDef->cd_flags |= CDPROCESSEDGDS;
 
 done:
     HashKill(&calmaLayerHash);
@@ -593,7 +733,71 @@ calmaElementSref()
      * Don't give it a use-id; we will do that only after
      * we've placed all cells.
      */
-    def = calmaFindCell(sname, NULL);
+    def = calmaLookCell(sname);
+    if (!def && (CalmaPostOrder || CalmaFlattenUses))
+    {
+	/* Force the GDS parser to read the cell definition in
+	 * post-order.  If cellname "sname" is not defined before
+	 * it is used, then read the cell definition by jumping
+	 * to its position in the stream file, reading that
+	 * instance, and then returning to the current file
+	 * position.  Note that this routine should be optimized
+	 * for the likely case where many cells are defined at
+	 * the end of the file; otherwise it will slow down the
+	 * read process excessively for large GDS files by
+	 * constantly moving from beginning to end of the file.
+	 *
+	 * Added by Nishit 8/16/2004
+	 */
+
+	off_t originalFilePos = calmaSetPosition(sname);
+	if (!feof(calmaInputFile))
+	{
+	    HashTable OrigCalmaLayerHash;
+	    int crsMultiplier = cifCurReadStyle->crs_multiplier;
+	    char *currentSname = cifReadCellDef->cd_name;
+
+	    OrigCalmaLayerHash = calmaLayerHash;
+	    cifReadCellDef->cd_client = (ClientData)calmaExact();
+
+	    /* Read cell definition "sname". */
+	    calmaParseStructure();
+
+	    /* Put things back to the way they were. */
+	    fseek(calmaInputFile, originalFilePos, SEEK_SET);
+	    cifReadCellDef = calmaLookCell(currentSname);
+	    def = calmaLookCell(sname);
+	    cifCurReadPlanes = (Plane **)cifReadCellDef->cd_client;
+	    cifReadCellDef->cd_client = (ClientData)NULL;
+	    calmaLayerHash = OrigCalmaLayerHash;
+	    if (crsMultiplier != cifCurReadStyle->crs_multiplier)
+	    {
+		int scalen, scaled;
+		if (crsMultiplier > cifCurReadStyle->crs_multiplier)
+		{
+		    scalen = crsMultiplier / cifCurReadStyle->crs_multiplier;
+		    scaled = 1;
+		}
+		else
+		{
+		    scalen = 1;
+		    scaled = cifCurReadStyle->crs_multiplier / crsMultiplier;
+		}
+		CIFScalePlanes(scalen, scaled, cifCurReadPlanes);
+	    }
+	}
+	else
+	{
+	    TxPrintf("Cell definition %s does not exist!\n", sname);
+	    fseek(calmaInputFile, originalFilePos, SEEK_SET);
+	    def = calmaFindCell(sname, NULL);
+	}
+    }
+    else
+    {
+	def = calmaFindCell(sname, NULL);
+    }
+
     if (DBIsAncestor(def, cifReadCellDef))
     {
 	calmaReadError("Cell %s is an ancestor of %s",
@@ -742,3 +946,36 @@ calmaFindCell(name, was_called)
 	if (was_called) *was_called = TRUE;
     return (CellDef *) HashGetValue(h);
 }
+
+/*
+ * ----------------------------------------------------------------------------
+ *
+ * calmaLookCell --
+ *
+ * This procedure is like calmaFindCell above, but it will not
+ * create a new subcell if the named cell does not already exist.
+ *
+ * Results:
+ *	The return value is a pointer to the definition for the
+ *	cell whose name is 'name', or NULL if cell 'name' does
+ *	not exist.
+ *
+ * Side effects:
+ *	None.
+ *
+ * ----------------------------------------------------------------------------
+ */
+
+CellDef *
+calmaLookCell(name)
+    char *name;		/* Name of desired cell */
+{
+    HashEntry *h;
+
+    h = HashLookOnly(&CifCellTable, name);
+    if (h == NULL)
+	return (CellDef *)NULL;
+    else
+	return (CellDef *)HashGetValue(h);
+}
+
