@@ -445,6 +445,10 @@ calmaElementPath()
     Rect segment;
     Plane *plane;
     int first,last;
+#ifdef NONMANHATTAN
+    CellUse *use;
+    CellDef *savedef, *newdef = NULL;
+#endif
 
     /* Skip CALMA_ELFLAGS, CALMA_PLEX */
     calmaSkipSet(calmaElementIgnore);
@@ -512,9 +516,60 @@ calmaElementPath()
     else
     {
 	plane = cifCurReadPlanes[ciftype];
+
+#ifdef NONMANHATTAN
+	if (CalmaSubcellPolygons && (calmaNonManhattan > 0))
+	{
+	    /* Place the polygon in its own subcell */
+	    char newname[] = "polygonXXXXX";
+	    HashEntry *he;
+
+	    savedef = cifReadCellDef;
+
+	    /* Make up name for cell */
+	    sprintf(newname + 7, "%05d", ++CalmaPolygonCount);
+
+	    he = HashFind(&calmaDefInitHash, newname);
+	    if (!HashGetValue(he))
+	    {
+		newdef = calmaFindCell(newname, NULL);
+		cifReadCellDef = newdef;
+		DBCellClearDef(cifReadCellDef);
+		DBCellSetAvail(cifReadCellDef);
+
+		/* cifEditCellPlanes is not used by the gds reader, so it's */
+		/* available to be used to store the polygon.		*/
+
+		cifCurReadPlanes = cifEditCellPlanes;
+		if (plane != NULL)
+		    plane = cifCurReadPlanes[ciftype];
+	    }
+	}
+#endif /* NONMANHATTAN */
+
 	CIFPaintWirePath(pathheadp, width,
 		(pathtype == CALMAPATH_SQUAREFLUSH) ? FALSE : TRUE,
 		plane, CIFPaintTable, (PaintUndoInfo *)NULL);
+
+#ifdef NONMANHATTAN
+	if (cifCurReadPlanes == cifEditCellPlanes)
+	{
+	    CIFPaintCurrent();
+	    DBReComputeBbox(cifReadCellDef);
+	    DRCCheckThis(cifReadCellDef, TT_CHECKPAINT, &cifReadCellDef->cd_bbox);
+	    DBWAreaChanged(cifReadCellDef, &cifReadCellDef->cd_bbox,
+			DBW_ALLWINDOWS, &DBAllButSpaceBits);
+	    DBCellSetModified(cifReadCellDef, TRUE);
+	    DBGenerateUniqueIds(cifReadCellDef, FALSE);  /* Is this necessary? */
+
+	    cifCurReadPlanes = cifSubcellPlanes;
+	    cifReadCellDef = savedef;
+
+	    use = DBCellNewUse(newdef, (char *)NULL);
+	    DBSetTrans(use, &GeoIdentityTransform);
+	    DBPlaceCell(use, cifReadCellDef);
+	}
+#endif /* NONMANHATTAN */
     }
 }
 
