@@ -83,6 +83,7 @@ static CIFLayer *CurCifLayer;
     (dst)->r_xtop = (src)->r_xtop * scale; \
     (dst)->r_ytop = (src)->r_ytop * scale;
 
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -374,6 +375,7 @@ cifHierErrorFunc(tile, checkArea)
     CIFError(&area, "parent and child disagree on CIF");
     return 0;
 }
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -402,20 +404,36 @@ cifHierCheckFunc(tile, plane)
     Rect area;
 
     TiToRect(tile, &area);
-    (void) DBSrPaintArea((Tile *) NULL, plane, &area,
-	&DBSpaceBits, cifHierErrorFunc, (ClientData) &area);
 
 #ifdef NONMANHATTAN
+
     if (IsSplit(tile))
+    {
+        DBSrPaintNMArea((Tile *)NULL, plane, TiGetTypeExact(tile),
+		&area, &DBSpaceBits, cifHierErrorFunc, (ClientData) &area);
+
 	DBNMPaintPlane(plane, TiGetTypeExact(tile), &area, CIFEraseTable,
 		(PaintUndoInfo *) NULL);
+    }
     else
-#endif  
+    {
+        DBSrPaintArea((Tile *) NULL, plane, &area,
+		&DBSpaceBits, cifHierErrorFunc, (ClientData) &area);
+        DBPaintPlane(plane, &area, CIFEraseTable, (PaintUndoInfo *) NULL);
+    }
+
+#else
+
+    DBSrPaintArea((Tile *) NULL, plane, &area,
+		&DBSpaceBits, cifHierErrorFunc, (ClientData) &area);
     DBPaintPlane(plane, &area, CIFEraseTable, (PaintUndoInfo *) NULL);
-    CIFTileOps += 1;
+
+#endif  
+
+    CIFTileOps++;
     return 0;
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -486,6 +504,7 @@ cifCheckAndErase(style)
     for (i=0; i<style->cs_nLayers; i++)
     {
 	CIFErrorLayer = i;
+	if (CIFComponentPlanes[i] == NULL) continue;
 	(void) DBSrPaintArea((Tile *) NULL, CIFComponentPlanes[i],
 	    &TiPlaneRect, &CIFSolidBits, cifHierCheckFunc,
 	    (ClientData) CIFTotalPlanes[i]);
@@ -844,15 +863,26 @@ cifHierArrayFunc(scx, output)
     Rect childArea, parentArea, A, B, C, D, expandedArea;
     CellUse *use;
     int radius, xsep, ysep, xsize, ysize, nx, ny, i, oldTileOps;
+    int xhi, yhi;
     bool anyInteractions = FALSE;
 
-#define IMPOSSIBLE 100000
-
     use = scx->scx_use;
     radius = CIFCurStyle->cs_radius;
     if ((use->cu_xlo == use->cu_xhi) && (use->cu_ylo == use->cu_yhi))
 	return 2;
     
+    /* We only want interactions between neighboring cells, so reduce	*/
+    /* the array size to at most 2x2, process, then restore the		*/
+    /* original array count.						*/
+
+    xhi = use->cu_xhi;
+    yhi = use->cu_yhi;
+
+    if (use->cu_xlo != use->cu_xhi)
+	use->cu_xhi = use->cu_xlo + ((use->cu_xlo < use->cu_xhi) ? 1 : -1);
+    if (use->cu_ylo != use->cu_yhi)
+	use->cu_yhi = use->cu_ylo + ((use->cu_ylo < use->cu_yhi) ? 1 : -1);
+
     /* Compute the sizes and separations of elements, in coordinates
      * of the parent.  If the array is 1-dimensional, we set the
      * corresponding spacing to an impossibly large distance.
@@ -860,11 +890,18 @@ cifHierArrayFunc(scx, output)
     
     childArea.r_xbot = 0;
     childArea.r_ybot = 0;
+
+    /* Ensure that array width or height 1 corresponds to a separation	*/
+    /* large enough not to satisfy any conditions A, B, C, or D.	*/
+
     if (use->cu_xlo == use->cu_xhi)
-	childArea.r_xtop = IMPOSSIBLE;
+	childArea.r_xtop = radius +
+		(use->cu_def->cd_bbox.r_xtop - use->cu_def->cd_bbox.r_xbot);
     else childArea.r_xtop = use->cu_xsep;
     if (use->cu_ylo == use->cu_yhi)
-	childArea.r_ytop = IMPOSSIBLE;
+	childArea.r_ytop = radius +
+		(use->cu_def->cd_bbox.r_ytop - use->cu_def->cd_bbox.r_ybot);
+
     else childArea.r_ytop = use->cu_ysep;
     GeoTransRect(&use->cu_transform, &childArea, &parentArea);
     xsep = parentArea.r_xtop - parentArea.r_xbot;
@@ -877,20 +914,6 @@ cifHierArrayFunc(scx, output)
     ny = (use->cu_bbox.r_ytop - use->cu_bbox.r_ybot - ysize)/ysep;
     ny += 1;
 
-    /* If the elements are spaced so closely together that two
-     * non-adjacent elements could conceivably interact, warn the
-     * user:  there's no guarantee that we'll generate CIF correctly
-     * for this.
-     */
-
-    if ((xsep+xsep-xsize < radius) || (ysep+ysep-ysize < radius))
-    {
-	TxError("CIF warning for array %s (instances of %s):\n",
-		use->cu_id, use->cu_def->cd_name);
-	TxError("    cells are so small and close together that two\n");
-	TxError("    non-adjacent cells could have interacting CIF!\n");
-    }
-
     /* Process each of the four areas A, B, C, and D.  For each one,
      * do three things:  yank the relevant material into cell
      * __CIF__, and generate a piece of CIF corresponding to each
@@ -966,111 +989,116 @@ cifHierArrayFunc(scx, output)
 		FALSE, TRUE);
     }
 
-    if (!anyInteractions)
+    if (anyInteractions)
     {
-	cifHierCleanup();
-	return 2;
+
+	/* Remove redundant CIF that's already in the children, and
+	 * make sure everything in the kids is in the parent too.
+	 */
+    
+	CIFErrorDef = use->cu_parent;
+	cifCheckAndErase(CIFCurStyle);
+
+	/* Lastly, paint everything back from our local planes into
+	 * the planes of the caller.  In doing this, stuff has to
+	 * be replicated many times over to cover each of the array
+	 * interaction areas.
+	 */
+    
+	oldTileOps = CIFTileOps;
+	for (i=0; i<CIFCurStyle->cs_nLayers; i++)
+	{
+	    int scale = CIFCurStyle->cs_scaleFactor;
+	    Rect cifArea;
+
+	    cifHierCurPlane = output[i];
+	    CurCifLayer = CIFCurStyle->cs_layers[i]; /* for growSliver */
+
+	    /* The left edge of the array (from A). */
+
+	    if ((ny > 1) && (ysep < ysize + radius))
+	    {
+		cifHierYSpacing = ysep * scale;
+		cifHierXSpacing = 0;
+		cifHierXCount = 1;
+		cifHierYCount = ny-1;
+		SCALE(&A, scale, &cifArea);
+		(void) DBSrPaintArea((Tile *) NULL, CIFTotalPlanes[i],
+			&cifArea, &CIFSolidBits, cifHierPaintArrayFunc,
+			(ClientData) NULL);
+	    }
+
+	    /* The top edge of the array (from C). */
+
+	    if ((nx > 1) && (xsep < xsize + radius))
+	    {
+		cifHierXSpacing = -xsep * scale;
+		cifHierYSpacing = 0;
+		cifHierXCount = nx-1;
+		cifHierYCount = 1;
+		SCALE(&C, scale, &cifArea);
+		(void) DBSrPaintArea((Tile *) NULL, CIFTotalPlanes[i],
+			&cifArea, &CIFSolidBits, cifHierPaintArrayFunc,
+			(ClientData) NULL);
+	    }
+
+	    if ((nx > 1) && (ny > 1) && (xsep < xsize + radius)
+	    		&& (ysep < ysize + radius))
+	    {
+		/* The bottom edge of the array (from B). */
+
+		cifHierXSpacing = xsep * scale;
+		cifHierYSpacing = 0;
+		cifHierXCount = nx-1;
+		cifHierYCount = 1;
+		SCALE(&B, scale, &cifArea);
+		(void) DBSrPaintArea((Tile *) NULL, CIFTotalPlanes[i],
+			&cifArea, &CIFSolidBits, cifHierPaintArrayFunc,
+			(ClientData) NULL);
+	    
+		/* The right edge of the array (from D). */
+
+		cifHierXSpacing = 0;
+		cifHierYSpacing = -ysep * scale;
+		cifHierXCount = 1;
+		cifHierYCount = ny-1;
+		SCALE(&D, scale, &cifArea);
+		(void) DBSrPaintArea((Tile *) NULL, CIFTotalPlanes[i],
+			&cifArea, &CIFSolidBits, cifHierPaintArrayFunc,
+			(ClientData) NULL);
+	    
+		/* The core of the array (from A and B).  This code is a bit
+		 * tricky in order to work correctly even for arrays where
+		 * radius < ysep.  The "if" statement handles this case.
+		 */
+
+		cifHierXSpacing = xsep * scale;
+		cifHierYSpacing = ysep * scale;
+		cifHierXCount = nx-1;
+		cifHierYCount = ny-1;
+		parentArea.r_xbot = A.r_xtop - xsep;
+		parentArea.r_ybot = A.r_ytop - ysep;
+		if (parentArea.r_ybot > B.r_ytop) parentArea.r_ybot = B.r_ytop;
+		parentArea.r_xtop = A.r_xtop;
+		parentArea.r_ytop = A.r_ytop;
+		SCALE(&parentArea, scale, &cifArea);
+		(void) DBSrPaintArea((Tile *) NULL, CIFTotalPlanes[i],
+			&cifArea, &CIFSolidBits, cifHierPaintArrayFunc,
+			(ClientData) NULL);
+	    }
+	}
+	CIFHierRects += CIFTileOps - oldTileOps;
     }
 
-    /* Remove redundant CIF that's already in the children, and
-     * make sure everything in the kids is in the parent too.
-     */
-    
-    CIFErrorDef = use->cu_parent;
-    cifCheckAndErase(CIFCurStyle);
-
-    /* Lastly, paint everything back from our local planes into
-     * the planes of the caller.  In doing this, stuff has to
-     * be replicated many times over to cover each of the array
-     * interaction areas.
-     */
-    
-    oldTileOps = CIFTileOps;
-    for (i=0; i<CIFCurStyle->cs_nLayers; i++)
-    {
-	int scale = CIFCurStyle->cs_scaleFactor;
-	Rect cifArea;
-
-	cifHierCurPlane = output[i];
-	CurCifLayer = CIFCurStyle->cs_layers[i]; /* for growSliver */
-
-	/* The left edge of the array (from A). */
-
-	if ((ny > 1) && (ysep < ysize + radius))
-	{
-	    cifHierYSpacing = ysep * scale;
-	    cifHierXSpacing = 0;
-	    cifHierXCount = 1;
-	    cifHierYCount = ny-1;
-	    SCALE(&A, scale, &cifArea);
-	    (void) DBSrPaintArea((Tile *) NULL, CIFTotalPlanes[i],
-		&cifArea, &CIFSolidBits, cifHierPaintArrayFunc,
-		(ClientData) NULL);
-	}
-
-	/* The top edge of the array (from C). */
-
-	if ((nx > 1) && (xsep < xsize + radius))
-	{
-	    cifHierXSpacing = -xsep * scale;
-	    cifHierYSpacing = 0;
-	    cifHierXCount = nx-1;
-	    cifHierYCount = 1;
-	    SCALE(&C, scale, &cifArea);
-	    (void) DBSrPaintArea((Tile *) NULL, CIFTotalPlanes[i],
-		&cifArea, &CIFSolidBits, cifHierPaintArrayFunc,
-		(ClientData) NULL);
-	}
-
-	if ((nx > 1) && (ny > 1) && (xsep < xsize + radius)
-	    && (ysep < ysize + radius))
-	{
-	    /* The bottom edge of the array (from B). */
-
-	    cifHierXSpacing = xsep * scale;
-	    cifHierYSpacing = 0;
-	    cifHierXCount = nx-1;
-	    cifHierYCount = 1;
-	    SCALE(&B, scale, &cifArea);
-	    (void) DBSrPaintArea((Tile *) NULL, CIFTotalPlanes[i],
-		&cifArea, &CIFSolidBits, cifHierPaintArrayFunc,
-		(ClientData) NULL);
-	    
-	    /* The right edge of the array (from D). */
-
-	    cifHierXSpacing = 0;
-	    cifHierYSpacing = -ysep * scale;
-	    cifHierXCount = 1;
-	    cifHierYCount = ny-1;
-	    SCALE(&D, scale, &cifArea);
-	    (void) DBSrPaintArea((Tile *) NULL, CIFTotalPlanes[i],
-		&cifArea, &CIFSolidBits, cifHierPaintArrayFunc,
-		(ClientData) NULL);
-	    
-	    /* The core of the array (from A and B).  This code is a bit
-	     * tricky in order to work correctly even for arrays where
-	     * radius < ysep.  The "if" statement handles this case.
-	     */
-
-	    cifHierXSpacing = xsep * scale;
-	    cifHierYSpacing = ysep * scale;
-	    cifHierXCount = nx-1;
-	    cifHierYCount = ny-1;
-	    parentArea.r_xbot = A.r_xtop - xsep;
-	    parentArea.r_ybot = A.r_ytop - ysep;
-	    if (parentArea.r_ybot > B.r_ytop) parentArea.r_ybot = B.r_ytop;
-	    parentArea.r_xtop = A.r_xtop;
-	    parentArea.r_ytop = A.r_ytop;
-	    SCALE(&parentArea, scale, &cifArea);
-	    (void) DBSrPaintArea((Tile *) NULL, CIFTotalPlanes[i],
-		&cifArea, &CIFSolidBits, cifHierPaintArrayFunc,
-		(ClientData) NULL);
-	}
-    }
-    CIFHierRects += CIFTileOps - oldTileOps;
     cifHierCleanup();
+
+    /* Restore the array bounds of the array */
+    use->cu_xhi = xhi;
+    use->cu_yhi = yhi;
+
     return 2;
 }
+
 
 /*
  * ----------------------------------------------------------------------------
