@@ -16,7 +16,7 @@
  *     * of the United States of America may require an export license.    * 
  *     *********************************************************************
  *
- * rcsid "$Header: /ufs/repository/magic/cif/CIFint.h,v 1.6 2001/07/23 17:49:50 tim Exp $"
+ * rcsid "$Header: /usr/cvsroot/magic/cif/CIFint.h,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $"
  */
 
 #ifndef _CIFINT_H
@@ -43,6 +43,34 @@
  * or to grow by a certain amount.
  */
 
+typedef struct bloat_data
+{
+    int bl_plane;		/* Plane on which a bloat or squares
+				 * operation is valid.
+				 */
+    int bl_distance[TT_MAXTYPES];
+} BloatData;
+
+typedef struct squares_data
+{
+    int sq_border;
+    int sq_size;
+    int sq_sep;
+    int sq_gridx;		/* Only used for "squares-grid" */
+    int sq_gridy;		/* Only used for "squares-grid" */
+} SquaresData;
+
+typedef struct slots_data
+{
+    int sl_sborder;		/* short tile side */
+    int sl_ssize;
+    int sl_ssep;
+    int sl_lborder;		/* long tile side */
+    int sl_lsize;
+    int sl_lsep;
+    int sl_offset;
+} SlotsData;
+
 typedef struct cifop
 {
     TileTypeBitMask co_paintMask;/* Zero or more paint layers to consider. */
@@ -51,13 +79,8 @@ typedef struct cifop
 				 * below for the legal ones.
 				 */
     int co_distance;		/* Grow or shrink distance (if needed). */
-    int *co_bloats;		/* For CIFOP_BLOAT, CIFOP_BLOATMAX, and
-				 * CIFOP_BLOATMIN: distance to grow per layer.
-				 * Exception: For CIFOP_SQUARES,
-				 * [0] is the border around squares, [1]
-				 * is the size of each square, and [2] is
-				 * the distance between squares.  For other
-				 * operations, co_bloats is NULL (not used).
+    ClientData co_client;	/* Pointer to a BloatData, SquaresData, or
+				 * SlotsData structure, or NULL.
 				 */
     struct cifop *co_next;	/* Next in list of operations to perform. */
 } CIFOp;
@@ -71,32 +94,63 @@ typedef struct cifop
  * CIFOP_OR -		OR current results with the layers indicated by
  *			the masks.
  * CIFOP_GROW -		Grow the current results uniformly by co_distance.
+ * CIFOP_GROW_G -	Grow the current results to snap to the indicated grid.
  * CIFOP_SHRINK -	Shrink the current results uniformly by co_distance.
  * CIFOP_BLOAT -	Find layers in paintMask, then bloat selectively
- *			according to co_bloats, and OR the results into
- *			the current plane.
+ *			according to bl_distance, and OR the results into
+ *			the current plane
  * CIFOP_SQUARES -	Generates a pattern of squares (used for making
  *			contact vias.  Each square is co_distance large,
  *			the squares are separated from each other by
  *			co_distance, and they are inside the edge of
  *			the material by at least co_distance.
+ * CIFOP_SLOTS -	Generate a pattern of rectangles (used for making
+ *			slots and slot vias).  Similar to squares except
+ *			for different dimensions in short and long tile
+ *			dimensions. "0" for the long size indicates that
+ *			the slot should extend the length of the tile
+ *			minus the long-side border length.
  * CIFOP_BLOATMAX -	Like CIFOP_BLOAT, except whole side of tile gets
  *			bloated by same amount, which is max bloat from
  *			anywhere along side.  Bloats can be negative.
  * CIFOP_BLOATMIN -	Same as CIFOP_BLOAT, except use min bloat from
  *			anywhere along side.
+ * CIFOP_BLOATALL -	Added 3/21/05---bloat to encompass all connected
+ *			material of the indicated type(s).
+ * CIFOP_BBOX -		Added 4/2/05---create a single rectangle encompassing
+ *			the cell bounding box.  This involves no magic type
+ *			layers but may itself be acted upon with grow/shrink
+ *			rules.
  */
 
 #define CIFOP_AND	1
 #define CIFOP_OR	2
 #define CIFOP_GROW	3
-#define CIFOP_SHRINK	4
-#define CIFOP_BLOAT	5
-#define CIFOP_SQUARES	6
-#define CIFOP_BLOATMAX	7
-#define CIFOP_BLOATMIN	8
-#define CIFOP_ANDNOT	9
-#define CIFOP_SQUARES_G	10
+#define CIFOP_GROW_G	4
+#define CIFOP_SHRINK	5
+#define CIFOP_BLOAT	6
+#define CIFOP_SQUARES	7
+#define CIFOP_SLOTS	8
+#define CIFOP_BLOATMAX	9
+#define CIFOP_BLOATMIN	10
+#define CIFOP_BLOATALL	11
+#define CIFOP_ANDNOT	12
+#define CIFOP_SQUARES_G	13
+#define CIFOP_BBOX	14
+
+/* Added by Tim 10/21/2004 */
+/* The following structure is used to pass information on how to draw
+ * contact subcell arrays for a specific magic contact tile type.  For
+ * the GDS write routine, the GDS file (FILE *) is passed as the client
+ * data.
+ */
+
+typedef struct cifsquaresinfo
+{
+    SquaresData	*csi_squares;	/* Information on how to generate squares */
+    TileType	 csi_type;	/* Magic contact tile type */
+    ClientData	 csi_client;	/* Used to pass output file info.	*/
+} CIFSquaresInfo;
 
 /* The following data structure contains all the information about
  * a particular CIF layer.
@@ -140,9 +194,12 @@ typedef struct
  *
  * CIF_TEMP:	Means that this is a temporary layer used to build
  *		up CIF information.  It isn't output in the CIF file.
+ * CIF_BBOX_TOP:  Indicates that the bounding box rectangle should
+ *		only be generated if the cell is a top-level cell.
  */
 
-#define CIF_TEMP 1
+#define CIF_TEMP 	1
+#define CIF_BBOX_TOP	2
 
 /* The following data structure describes a complete set of CIF
  * layers.  The number of CIF layers (MAXCIFLAYERS) must not be
@@ -208,7 +265,9 @@ typedef struct cifstyle
 } CIFStyle;
 
 /* values for cs_flags */
-#define CWF_PERMISSIVE_LABELS 1
+#define CWF_PERMISSIVE_LABELS	1
+#define CWF_GROW_SLIVERS	2
+#define CWF_ANGSTROMS 		4
 
 /* procedures */
 
