@@ -930,7 +930,7 @@ is_clockwise(pathHead)
 	}
     }
 
-    if (!midx) return TRUE;   /* single-point polygon? */
+    if (!midx) return TRUE;	/* one-point polygon? */
 
     /* Rare case of colinear points (implies degenerate polygon) requires */
     /* moving along pointlist until points are not colinear and repeating */
