@@ -41,12 +41,6 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/cif/
 #include "utils/malloc.h"
 #include "cif/cif.h"
 
-/* The following points to a list of all CIF styles currently
- * understood:
- */
-
-CIFKeep *CIFStyleList = NULL;
-
 /* The following statics are used to keep track of things between
  * calls to CIFTechLine.
  */
@@ -67,28 +61,25 @@ TileTypeBitMask CIFSolidBits;
 void cifTechStyleInit();
 bool cifCheckCalmaNum();
 
-
 /*
  * ----------------------------------------------------------------------------
  *
- * cifTechNewStyle --
+ * cifTechFreeStyle --
  *
- * 	This procedure creates a new CIF style at the end of
- *	the list of style and initializes it to completely
- *	null.
+ * 	This procedure frees memory for the current CIF style, and
+ *	sets the current style to NULL.
  *
  * Results:
  *	None.
  *
  * Side effects:
- *	A new element is added to the end of CIFStyleList, and CIFCurStyle
- *	is set to point to it.
+ *	Memory is free'd.
  *
  * ----------------------------------------------------------------------------
  */
 
 void
-cifTechNewStyle()
+cifTechFreeStyle()
 {
     int i;
     CIFOp	*op;
@@ -115,8 +106,34 @@ cifTechNewStyle()
 		freeMagic((char *)layer);
 	    }
 	}
+	freeMagic(CIFCurStyle);
+	CIFCurStyle = NULL;
     }
-    CIFCurStyle = (CIFStyle *) mallocMagic(sizeof(CIFStyle));
+}
+
+/*
+ * ----------------------------------------------------------------------------
+ *
+ * cifTechNewStyle --
+ *
+ * 	This procedure creates a new CIF style at the end of
+ *	the list of style and initializes it to completely
+ *	null.
+ *
+ * Results:
+ *	None.
+ *
+ * Side effects:
+ *	A new element is added to the end of CIFStyleList, and CIFCurStyle
+ *	is set to point to it.
+ *
+ * ----------------------------------------------------------------------------
+ */
+
+void
+cifTechNewStyle()
+{
+    cifTechFreeStyle();
     cifTechStyleInit();
 }
 
@@ -135,6 +152,9 @@ cifTechStyleInit()
 {
     int i;
 
+    if (CIFCurStyle == NULL)
+	CIFCurStyle = (CIFStyle *) mallocMagic(sizeof(CIFStyle));
+
     CIFCurStyle->cs_name = NULL;
     CIFCurStyle->cs_status = TECH_NOT_LOADED;
 
@@ -317,9 +337,7 @@ CIFTechInit()
 
     /* Cleanup any old info. */
 
-    cifTechNewStyle();
-    freeMagic(CIFCurStyle);
-    CIFCurStyle = NULL;
+    cifTechFreeStyle();
 
     /* forget the list of styles */
 
@@ -1722,6 +1740,7 @@ CIFLoadStyle(stylename)
     invcif = TechSectionGetMask("cifoutput", NULL);
     TechLoad(NULL, invcif);
 
+    /* CIFTechFinal(); */  /* handled by TechLoad() */
     CIFTechOutputScale(DBLambda[0], DBLambda[1]);
 }
 
