@@ -22,9 +22,7 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/comm
 
 #include <stdio.h>
 #include <stdlib.h>
-#ifdef SYSV
 #include <string.h>
-#endif
 
 #include "tcltk/tclmagic.h"
 #include "utils/magic.h"
@@ -499,7 +497,9 @@ outputCalma:
  * or
  *	cellname [list] topcells|allcells|window
  * or
- *	cellname delete|lock|unlock [name]
+ *	cellname delete [name]
+ * or
+ *	cellname writeable [name] [true|false]
  * or
  *	cellname rename [name] [newname]
  *
@@ -542,16 +542,14 @@ CmdCellname(w, cmd)
 	"create		create a new cell definition",
 	"delete		delete the named cell definition",
 	"flags		list option flags of the indicated cell definition",
-	"lock		lock the cell definition (make read-only)",
 	"rename		rename the indicated cell",
-	"unlock		unlock the cell definition (make writeable)",
+	"writeable	make the cell definition read-only or read-write",
 	NULL
     };
     typedef enum { IDX_CHILDREN, IDX_PARENTS, IDX_EXISTS, IDX_SELF,
 		   IDX_INSTANCE, IDX_CHILDINST, IDX_CELLDEF, IDX_ALLCELLS,
 		   IDX_TOPCELLS, IDX_IN_WINDOW, IDX_CREATE,
-		   IDX_DELETE, IDX_FLAGS, IDX_LOCK, IDX_RENAME,
-		   IDX_UNLOCK } optionType;
+		   IDX_DELETE, IDX_FLAGS, IDX_RENAME, IDX_READWRITE } optionType;
 
     if (strstr(cmd->tx_argv[0], "in"))
 	func = DBUsePrint;
@@ -570,7 +568,10 @@ CmdCellname(w, cmd)
     option = Lookup(cmd->tx_argv[1 + ((dolist) ? 1 : 0)], cmdCellOption);
     if (option < 0) goto badusage;
 
-    if ((locargc > 3) && (option != IDX_RENAME)) goto badusage;
+    if ((locargc > 3) && (option != IDX_RENAME) && (option != IDX_DELETE) &&
+		(option != IDX_READWRITE))
+	goto badusage;
+
     if (locargc >= 3) {
 	switch (option) {
 	    case IDX_ALLCELLS:
@@ -591,7 +592,7 @@ CmdCellname(w, cmd)
 	    case IDX_TOPCELLS:
 		TxError("Instances do not have a top level.  Use \"cellname\"?\n");
 		return;
-	    case IDX_IN_WINDOW: case IDX_LOCK: case IDX_UNLOCK: case IDX_FLAGS:
+	    case IDX_IN_WINDOW: case IDX_READWRITE: case IDX_FLAGS:
 		TxError("Function unimplemented for instances.\n");
 		return;
 	    case IDX_DELETE:
@@ -643,16 +644,101 @@ CmdCellname(w, cmd)
 	    else
 	        DBCellDelete(cellname, FALSE);
 	    break;
-	case IDX_LOCK:
-	    cellDef = DBCellLookDef(cellname);
-	    cellDef->cd_flags |= CDNOEDIT;
-	    break;
-	case IDX_UNLOCK:
-	    cellDef = DBCellLookDef(cellname);
-	    cellDef->cd_flags &= ~CDNOEDIT;
+
+	case IDX_READWRITE:
+	    if (cellname == NULL)
+		cellDef = EditRootDef;
+	    else
+		cellDef = DBCellLookDef(cellname);
+	    if (cellDef == (CellDef *) NULL)
+	    {
+		TxError("Unknown cell %s\n", cellname);
+		break;
+	    }
+
+	    if (locargc == 3)
+	    {
+		if (cellDef->cd_flags & CDNOEDIT)
+#ifdef MAGIC_WRAPPER
+		    if (dolist)
+			Tcl_SetResult(magicinterp, "read-only", 0);
+		    else
+#endif
+		    TxPrintf("read-only\n");
+		else
+#ifdef MAGIC_WRAPPER
+		    if (dolist)
+			Tcl_SetResult(magicinterp, "writeable", 0);
+		    else
+#endif
+		    TxPrintf("writeable\n");
+	    }
+	    else if (locargc == 4)
+	    {
+		if (tolower(*cmd->tx_argv[3 + ((dolist) ? 1 : 0)]) == 't')
+		{
+		    /* Check if file is already read-write */
+		    if (!(cellDef->cd_flags & CDNOEDIT))
+			break;
+
+		    /* Make file read-write */
+
+#ifdef FILE_LOCKS
+		    if (cellDef->cd_fd == -1)
+			dbReadOpen(cellDef, NULL, TRUE);
+
+		    if (cellDef->cd_fd != -1)
+			cellDef->cd_flags &= ~CDNOEDIT;
+		    else
+			TxError("Advisory lock held on cell %s\n", cellDef->cd_name);
+#else
+		    cellDef->cd_flags &= ~CDNOEDIT;
+#endif
+		    WindAreaChanged(w, &w->w_screenArea);
+		    CmdSetWindCaption(EditCellUse, EditRootDef);
+		}
+		else	/* "cellname writeable false" */
+		{
+		    /* Check if file is already read-only */
+		    if (cellDef->cd_flags & CDNOEDIT)
+			break;
+
+		    /* Make file read-only */
+
+		    cellDef->cd_flags |= CDNOEDIT;
+
+#ifdef FILE_LOCKS
+		    /* Release any advisory lock held on this file */
+
+		    if (cellDef->cd_fd != -1)
+		    {
+			close(cellDef->cd_fd);
+			cellDef->cd_fd = -1;
+		    }
+#endif
+
+		    if (EditCellUse && (EditCellUse->cu_def == cellDef))
+			EditCellUse = (CellUse *)NULL;
+
+		    if (EditRootDef == cellDef)
+			EditRootDef = (CellDef *)NULL;
+
+		    WindAreaChanged(w, &w->w_screenArea);
+		    CmdSetWindCaption(EditCellUse, (CellDef *)NULL);
+		}
+	    }
 	    break;
+
 	case IDX_FLAGS:
-	    cellDef = DBCellLookDef(cellname);
+	    if (cellname == NULL)
+		cellDef = EditRootDef;
+	    else
+		cellDef = DBCellLookDef(cellname);
+	    if (cellDef == (CellDef *) NULL)
+	    {
+		TxError("Unknown cell %s\n", cellname);
+		break;
+	    }
 #ifdef MAGIC_WRAPPER
 	    if (cellDef->cd_flags & CDAVAILABLE)
 		Tcl_AppendElement(magicinterp, "available");
@@ -692,159 +778,10 @@ badusage:
     TxError("or:    %s [list] allcells|topcells|window\n", cmd->tx_argv[0]);
     TxError("or:    %s create name\n", cmd->tx_argv[0]);
     TxError("or:    %s rename name newname\n", cmd->tx_argv[0]);
+    TxError("or:    %s writeable [name] [true|false]\n", cmd->tx_argv[0]);
     return;
 }
 
-#ifdef MAGIC_WRAPPER
-/*
- * ----------------------------------------------------------------------------
- *
- * CmdCellsearch --
- *
- *	This is a low-level search command that allows a hierarchical cell
- *	search to execute a TCL procedure on each cell definition or cell
- *	use found.
- *
- *	Use: cellsearch [instances] <tcl_procedure>
- *
- *	If "instances" is present, then the cell search is over all cell
- *	uses, and <tcl_procedure> takes a list containing 4 integer values
- *	representing the bounding box (llx, lly, urx, ury) of the cell,
- *	and two string values containing the name of the cell use and the
- *	cell definition, respectively.
- *
- *	If "instances" is *not* present, then the cell search is over each
- *	cell definition, and <tcl_procedure> takes one value, which is the
- *	name of the cell.
- *
- * ----------------------------------------------------------------------------
- */
-
-void
-CmdCellsearch(w, cmd)
-    MagWindow *w;
-    TxCommand *cmd;
-{
-    SearchContext scx;
-    int xMask, windowMask;
-    char *tclproc, *pptr;
-    int cmdTclProcSrCellFunc();     /* Fwd declaration */
-    int cmdTclProcCellDefFunc();     /* Fwd declaration */
-    CellDef *rootBoxDef;
-    MagWindow *window;
-
-    bzero(&scx, sizeof(SearchContext));
-    if (!ToolGetBox (&rootBoxDef, NULL))
-    {
-	TxError ("Box tool must be present\n");
-	return;
-    }
-    window = ToolGetBoxWindow (&scx.scx_area, &windowMask);
-    if (!window)
-    {
-	TxError ("Box tool does not exist in any window\n");
-	return;
-    }
-    xMask = ((DBWclientRec *)window->w_clientData)->dbw_bitmask;
-    if ((windowMask & ~xMask) != 0)
-    {
-	window = CmdGetRootPoint((Point *) NULL, (Rect *) NULL);
-	xMask = ((DBWclientRec *) window->w_clientData)->dbw_bitmask;
-	if ((windowMask & xMask) == 0)
-	{
-	    TxPrintf("The box is in more than one window;  use the cursor\n");
-	    TxPrintf("to select the one you want to select from.\n");
-	    return;
-	}
-    }
-    scx.scx_use = (CellUse *) window->w_surfaceID;
-    scx.scx_trans = GeoIdentityTransform;
-
-    if ((cmd->tx_argc == 1) || (cmd->tx_argc > 3))
-    {
-	TxError("Usage: cellsearch [instances] <tcl_procedure>\n");
-	return;
-    }
-
-    pptr = cmd->tx_argv[cmd->tx_argc - 1];
-    if (*pptr == '{')           /* in-line procedure */
-    {
-	tclproc = StrDup(NULL, pptr + 1);
-	pptr = tclproc + strlen(tclproc) - 1;
-	if (*pptr == '}') *pptr = '\0';
-    }
-    else
-	tclproc = StrDup(NULL, cmd->tx_argv[cmd->tx_argc - 1]);
-
-    if ((cmd->tx_argc == 3) && (!strncmp(cmd->tx_argv[1], "inst", 4)))
-    {
-	DBTreeSrTiles(&scx, xMask, cmdTclProcSrCellFunc,
-		(ClientData) tclproc);
-    }
-    else
-    {
-	DBCellSrDefs(0, cmdTclProcCellDefFunc, (ClientData) tclproc);
-    }
-    freeMagic(tclproc);
-}   
-
-/*
- * cmdTclProcSrCellFunc --
- *  
- * Filter procedure applied to cell instances by cmdCellsearch() above.
- */ 
-  
-int
-cmdTclProcSrCellFunc(scx, tclproc)
-    SearchContext *scx;
-    char *tclproc;
-{
-    Rect rootRect;
-    char evalstr[512];
-    int rval;
-    CellDef *def;
-
-    def = scx->scx_use->cu_def;
-    GeoTransRect(&scx->scx_trans, &def->cd_bbox, &rootRect);
-
-    sprintf(evalstr, "%s %d %d %d %d %s %s", tclproc, rootRect.r_xbot,
-		rootRect.r_ybot, rootRect.r_xtop, rootRect.r_ytop,
-		def->cd_name, scx->scx_use->cu_id);
-
-    rval = Tcl_EvalEx(magicinterp, evalstr, -1, 0);
-    if (rval != TCL_OK) return 1;
-
-    /* Allow interrupts in case something goes wrong with the Tcl procedure */
-    if (SigInterruptPending) return 1;
-    return 0;
-}   
-
-/*
- * cmdTclProcCellDefFunc --
- *  
- * Filter procedure applied to celldefs by cmdCellsearch() above.
- */ 
-  
-int
-cmdTclProcCellDefFunc(def, tclproc)
-    CellDef *def;
-    char *tclproc;
-{
-    char evalstr[512];
-    int rval;
-
-    sprintf(evalstr, "%s %s", tclproc, def->cd_name);
-
-    rval = Tcl_EvalEx(magicinterp, evalstr, -1, 0);
-    if (rval != TCL_OK) return 1;
-
-    /* Allow interrupts in case something goes wrong with the Tcl procedure */
-    if (SigInterruptPending) return 1;
-    return 0;
-}   
-
-#endif
-
 /*
  * ----------------------------------------------------------------------------
  *
@@ -996,7 +933,21 @@ CmdCif(w, cmd)
     switch (option)
     {
 	case ARRAY:
-	    if (argc != 3)
+	    if (argc == 4) {
+	        if (!strncmp(argv[2], "write", 5))
+		{
+		    if (!strncmp(argv[3], "dis", 3))
+			CIFArrayWriteDisable = TRUE;
+		    else if (!strncmp(argv[3], "en", 2))
+			CIFArrayWriteDisable = FALSE;
+		    else
+			TxPrintf("Subcell interaction output %s\n",
+				(CIFArrayWriteDisable) ? "disabled" : "enabled");
+		    return;
+		}
+		else goto wrongNumArgs;
+	    }
+	    else if (argc != 3)
 	    {
 		wrongNumArgs:
 		TxError("Wrong arguments in \"cif %s\" command:\n",
@@ -1015,7 +966,21 @@ CmdCif(w, cmd)
 	    return;
 	
 	case HIER:
-	    if (argc != 3) goto wrongNumArgs;
+	    if (argc == 4) {
+	        if (!strncmp(argv[2], "write", 5))
+		{
+		    if (!strncmp(argv[3], "dis", 3))
+			CIFHierWriteDisable = TRUE;
+		    else if (!strncmp(argv[3], "en", 2))
+			CIFHierWriteDisable = FALSE;
+		    else
+			TxPrintf("Subcell interaction output %s\n",
+				(CIFHierWriteDisable) ? "disabled" : "enabled");
+		    return;
+		}
+		else goto wrongNumArgs;
+	    }
+	    else if (argc != 3) goto wrongNumArgs;
 	    if (!ToolGetBox(&rootDef, &box))
 	    {
 		TxError("Use the box to select the area in");
@@ -1415,7 +1380,146 @@ CmdClockwise(w, cmd)
     badusage:
     TxError("Usage: %s [degrees]\n", cmd->tx_argv[0]);
 }
-
+
+/*
+ * ----------------------------------------------------------------------------
+ *
+ * CmdContact --
+ *
+ * Implement the "contact" command.
+ *
+ * Usage:
+ *	contact <type>
+ *
+ * Results:
+ *	None.
+ *
+ * Side effects:
+ *	The area in the box is searched for the intersection of all residues
+ *	of the contact type <type>.  The intersecting areas are replaced with
+ *	the contact type.
+ *
+ * ----------------------------------------------------------------------------
+ */
+
+typedef struct CCS
+{
+    CellDef *rootDef;
+    TileTypeBitMask *rmask;
+    TileType tstart;
+    Rect area;
+    LinkedRect *lhead;
+} CCStruct;
+
+void
+CmdContact(w, cmd)
+    MagWindow *w;
+    TxCommand *cmd;
+{
+    TileType type, rtype;
+    TileTypeBitMask *rmask, smask;
+    CCStruct ccs;
+    Rect area;
+    int cmdContactFunc();	/* Forward declaration */
+
+    windCheckOnlyWindow(&w, DBWclientID);
+    if ((w == (MagWindow *) NULL) || (w->w_client != DBWclientID))
+    {
+	TxError("Put the cursor in a layout window\n");
+	return;
+    }
+
+    if (cmd->tx_argc != 2)
+    {
+	TxError("Usage: %s <contact_type>\n", cmd->tx_argv[0]);
+	return;
+    }
+    if (!ToolGetEditBox(&area)) return;
+
+    type = DBTechNoisyNameType(cmd->tx_argv[1]);
+    if (type >= 0)
+    {
+	if (!DBIsContact(type))
+	{
+	    TxError("Error:  tile type \"%s\" is not a contact.\n",
+			cmd->tx_argv[1]);
+	    return;
+	}
+
+	/* Find the first residue type */
+	rmask = DBResidueMask(type);
+	for (rtype = 0; rtype < DBNumUserLayers; rtype++)
+	    if (TTMaskHasType(rmask, rtype))
+		break;
+
+	/* Find all tiles of one residue type */
+	ccs.lhead = (LinkedRect *)NULL;
+	ccs.rmask = rmask;
+	ccs.tstart = rtype;
+	ccs.rootDef = EditCellUse->cu_def;
+	TTMaskSetOnlyType(&smask, rtype);
+	DBSrPaintArea((Tile *) NULL, EditCellUse->cu_def->cd_planes[DBPlane(rtype)],
+		&area, &smask, cmdContactFunc, (ClientData) &ccs);
+
+	while (ccs.lhead != NULL)
+	{
+	    TTMaskSetOnlyType(&smask, type);
+	    DBPaintMask(EditCellUse->cu_def, &ccs.lhead->r_r, &smask);
+	    freeMagic(ccs.lhead);
+	    ccs.lhead = ccs.lhead->r_next;
+	}
+
+	/* Refresh the layout drawing */
+	DBWAreaChanged(EditCellUse->cu_def, &area, DBW_ALLWINDOWS, &smask);
+	DRCCheckThis (EditCellUse->cu_def, TT_CHECKPAINT, &area);
+    }
+}
+
+/* For each tile in the first residue type, search for tiles of the
+ * next residue type, and add the intersection of areas to the linked
+ * rectangle list.
+ */
+
+int
+cmdContactFunc(tile, ccs)
+    Tile *tile;
+    CCStruct *ccs;
+{
+    TileType stype;
+    TileTypeBitMask smask;
+    int cmdContactFunc2();	/* Forward declaration */
+
+    TiToRect(tile, &ccs->area);
+
+    for (stype = ccs->tstart + 1; stype < DBNumUserLayers; stype++)
+	if (TTMaskHasType(ccs->rmask, stype))
+	    break;
+
+    TTMaskSetOnlyType(&smask, stype);
+    DBSrPaintArea((Tile *) NULL, ccs->rootDef->cd_planes[DBPlane(stype)],
+		&ccs->area, &smask, cmdContactFunc2, (ClientData)ccs);
+    return 0;
+}
+
+int
+cmdContactFunc2(tile, ccs)
+    Tile *tile;
+    CCStruct *ccs;
+{
+    LinkedRect *newlr;
+    Rect area;
+    TiToRect(tile, &area);
+
+    GeoClip(&area, &ccs->area);
+
+    newlr = (LinkedRect *) mallocMagic(sizeof(LinkedRect));
+    newlr->r_r = area;
+    newlr->r_next = ccs->lhead;
+    ccs->lhead = newlr;
+
+    return 0;
+}
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -1498,7 +1602,11 @@ CmdCopy(w, cmd)
 		}
 	    }
 	}
-	else amountx = amounty = 1;
+	else
+	{
+	    amountx = cmdParseCoord(w, "1l", TRUE, TRUE);
+	    amounty = cmdParseCoord(w, "1l", TRUE, FALSE);
+	}
 
 	switch (indx)
 	{
@@ -1588,7 +1696,7 @@ copyToPoint:
     
     SelectCopy(&t);
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -2506,6 +2614,57 @@ cmdBevelFunc(tile, cxp)
 }
 #endif  /* NONMANHATTAN */
 
+/*
+ * ----------------------------------------------------------------------------
+ *
+ * CmdCrash --
+ *
+ * Save cells to or recover cells from a crash backup file
+ *
+ * Usage:
+ *	crash save|recover [file]
+ *
+ * Results:
+ *	None.
+ *
+ * Side effects:
+ *	Loads the database with multiple cells from the crash recovery
+ *	file, and removes the crash recovery file.
+ *
+ * ----------------------------------------------------------------------------
+ */
+void
+CmdCrash(w, cmd)
+    MagWindow *w;
+    TxCommand *cmd;
+{
+    int option;
+    char *filename = NULL;
+    static char *cmdCrashOpt[] = {"save", "recover", 0};
+
+    if (cmd->tx_argc > 3)
+	TxError("Usage: %s save|recover [filename]\n", cmd->tx_argv[0]);
+    else if (cmd->tx_argc >= 2)
+    {
+	option = Lookup(cmd->tx_argv[1], cmdCrashOpt);
+	if (option < 0)
+	{
+	    TxError("Usage: %s save|recover [filename]\n", cmd->tx_argv[0]);
+	    return;
+	}
+    }
+    if (cmd->tx_argc == 3) filename = cmd->tx_argv[2];
+
+    switch(option) {
+	case 0:			/* save */
+	    DBWriteBackup(filename);
+	    break;
+	case 1:			/* recover */
+	    DBFileRecovery(filename);
+	    break;
+    }
+}
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -2731,10 +2890,11 @@ cmdDownEnumFunc(selUse, use, transform, area)
 #define DRC_OFF		10
 #define DRC_ON		11
 #define DRC_STATUS	12
-#define PRINTRULES	13
-#define RULESTATS	14
-#define STATISTICS	15
-#define WHY		16
+#define DRC_STYLE	13
+#define PRINTRULES	14
+#define RULESTATS	15
+#define STATISTICS	16
+#define WHY		17
 
 void
 CmdDrc(w, cmd)
@@ -2752,8 +2912,12 @@ CmdDrc(w, cmd)
     char 	**msg;
     bool	wizardHelp;
     bool	incremental;
+    bool	doforall = FALSE;
+    bool	dolist = FALSE;
     int		count_total;
     DRCCountList *dcl, *dclsrch;
+    int argc = cmd->tx_argc;
+    char **argv = cmd->tx_argv;
 
     static char *cmdDrcOption[] =
     {	
@@ -2770,6 +2934,7 @@ CmdDrc(w, cmd)
 	"off                    turn off background checker",
 	"on                     reenable background checker",
 	"status			report if the drc checker is on or off",
+	"style			set the DRC style",
 	"printrules [file]      print out design rules in file or on tty",
 	"rulestats              print out stats about design rule database",
 	"statistics             print out statistics gathered by checker",
@@ -2777,27 +2942,37 @@ CmdDrc(w, cmd)
 	NULL
     };
 
-    if (cmd->tx_argc < 2)
+    if (argc < 2)
     {
 	TxError("No option given in \":drc\" command.\n");
 	option = DRC_HELP;
     }
     else
     {
-	option = Lookup(cmd->tx_argv[1], cmdDrcOption);
+	if (!strncmp(argv[1], "list", 4))
+	{
+	    dolist = TRUE;
+	    if (!strncmp(argv[1], "listall", 7))
+	    {
+		doforall = TRUE;
+	    }
+	    argv++;
+	    argc--;
+	}
+	option = Lookup(argv[1], cmdDrcOption);
 	if (option < 0)
 	{
-	    TxError("%s isn't a valid drc option.\n", cmd->tx_argv[1]);
+	    TxError("%s isn't a valid drc option.\n", argv[1]);
 	    option = DRC_HELP;
-	    cmd->tx_argc = 2;
+	    argc = 2;
 	}
-	if ((cmd->tx_argc > 2) && (option != PRINTRULES) && (option != FIND)
+	if ((argc > 2) && (option != PRINTRULES) && (option != FIND)
 	    && (option != SHOWINT) && (option != DRC_HELP) && (option != EUCLIDEAN)
-	    && (option != DRC_STEPSIZE) && (option != DRC_HALO) && (option != COUNT))
+	    && (option != DRC_STEPSIZE) && (option != DRC_HALO) && (option != COUNT)
+	    && (option != DRC_STYLE))
 	{
 	    badusage:
-	    TxError("Wrong arguments in \"drc %s\" command:\n",
-		cmd->tx_argv[1]);
+	    TxError("Wrong arguments in \"drc %s\" command:\n", argv[1]);
 	    TxError("    :drc %s\n", cmdDrcOption[option]);
 	    TxError("Try \":drc help\" for more help.\n");
 	    return;
@@ -2813,8 +2988,8 @@ CmdDrc(w, cmd)
 	    break;
 	
 	case SHOWINT:
-	    if (cmd->tx_argc != 3) goto badusage;
-	    radius = cmdParseCoord(w, cmd->tx_argv[2], TRUE, FALSE);
+	    if (argc != 3) goto badusage;
+	    radius = cmdParseCoord(w, argv[2], TRUE, FALSE);
 	    if (radius < 0)
 	    {
 		TxPrintf("Radius must not be negative\n");
@@ -2832,6 +3007,13 @@ CmdDrc(w, cmd)
 	    ToolMoveBox(TOOL_BL, &area.r_ll, FALSE, rootUse->cu_def);
 	    ToolMoveCorner(TOOL_TR, &area.r_ur, FALSE, rootUse->cu_def);
 	    break;
+
+	case DRC_STYLE:
+	    if (argc == 2)
+		DRCPrintStyle(dolist, doforall, !doforall);
+	    else
+		DRCSetStyle(argv[2]);
+	    break;
 	
 	case CATCHUP:
 	    DRCCatchUp();
@@ -2846,8 +3028,8 @@ CmdDrc(w, cmd)
 	
 	case COUNT:
 	    count_total = -1;
-	    if (cmd->tx_argc == 3)
-		if (!strncmp(cmd->tx_argv[2], "total", 5))
+	    if (argc == 3)
+		if (!strncmp(argv[2], "total", 5))
 		    count_total = 0;
 
 	    if ((window = w) == NULL)
@@ -2886,7 +3068,7 @@ CmdDrc(w, cmd)
 	    break;
 
 	case EUCLIDEAN:
-	    if (!strcmp(cmd->tx_argv[2], "on"))
+	    if (!strcmp(argv[2], "on"))
 		DRCEuclidean = TRUE;
 	    else
 		DRCEuclidean = FALSE;
@@ -2900,15 +3082,15 @@ CmdDrc(w, cmd)
 	    }
 	    else
 		rootArea = w->w_surfaceArea;
-	    if (cmd->tx_argc > 3) goto badusage;
+	    if (argc > 3) goto badusage;
 
 	    rootUse = (CellUse *) window->w_surfaceID;
 	    rootDef = rootUse->cu_def;
 
 	    incremental = FALSE;
-	    if (cmd->tx_argc == 3 && StrIsInt(cmd->tx_argv[2]))
+	    if (argc == 3 && StrIsInt(argv[2]))
 	    {
-		drc_nth = atoi(cmd->tx_argv[2]);
+		drc_nth = atoi(argv[2]);
 		if (drc_nth <= 0) drc_nth = 1;
 	    }
 	    else
@@ -2941,29 +3123,33 @@ CmdDrc(w, cmd)
 	    break;
 	
 	case DRC_HALO:
-	    if (cmd->tx_argc == 3)
+	    if (argc == 3)
 	    {
-		TechHalo = atoi(cmd->tx_argv[2]);
-		if (TechHalo > MaxHalo)
-		    TechHalo = MaxHalo;
+		DRCTechHalo = cmdScaleCoord(w, argv[2], FALSE, TRUE);
+		DRCTechHalo *= DRCCurStyle->DRCScaleFactor;
+		if (DRCTechHalo > DRCCurStyle->DRCTechHalo)
+		    DRCTechHalo = DRCCurStyle->DRCTechHalo;
 
-		if (TechHalo < MaxHalo)
+		if (DRCTechHalo < DRCCurStyle->DRCTechHalo)
 		    TxPrintf("Warning: rulechecking limited to halo of %d lambda.\n",
-				TechHalo);
+				DRCTechHalo / DRCCurStyle->DRCScaleFactor);
 		else
-		    TxPrintf("DRC checks all rules (halo of %d lambda)\n", TechHalo);
+		    TxPrintf("DRC checks all rules (halo of %d lambda)\n",
+				DRCTechHalo / DRCCurStyle->DRCScaleFactor);
 	    }
 	    else
 	    {
-		TxPrintf("DRC halo is %d lambda\n", TechHalo);
-		if (TechHalo != MaxHalo)
-		    TxPrintf("Maximum rule distance is %d lambda\n", MaxHalo);
+		TxPrintf("DRC halo is %d lambda\n",
+				DRCTechHalo / DRCCurStyle->DRCScaleFactor);
+		if (DRCTechHalo != DRCCurStyle->DRCTechHalo)
+		    TxPrintf("Maximum rule distance is %d lambda\n",
+			DRCCurStyle->DRCTechHalo / DRCCurStyle->DRCScaleFactor);
 	    }
 	    break;
 
 	case DRC_HELP:
-	    if ((cmd->tx_argc == 3)
-		    && (strcmp(cmd->tx_argv[2], "wizard") == 0))
+	    if ((argc == 3)
+		    && (strcmp(argv[2], "wizard") == 0))
 		wizardHelp = TRUE;
 	    else wizardHelp = FALSE;
 	    TxPrintf("DRC commands have the form \":drc option\",");
@@ -2996,12 +3182,12 @@ CmdDrc(w, cmd)
 	    break;
 	
 	case PRINTRULES:
-	    if (cmd->tx_argc > 3) goto badusage;
-	    if (cmd->tx_argc < 3)
+	    if (argc > 3) goto badusage;
+	    if (argc < 3)
 		fp = stdout;
-	    else if ((fp = fopen (cmd->tx_argv[2],"w")) == (FILE *) NULL)
+	    else if ((fp = fopen (argv[2],"w")) == (FILE *) NULL)
 	    {
-		TxError("Cannot write file %s\n", cmd->tx_argv[2]);
+		TxError("Cannot write file %s\n", argv[2]);
 		return;
 	    }
 	    DRCPrintRulesTable (fp);
@@ -3018,16 +3204,21 @@ CmdDrc(w, cmd)
 	    break;
 
 	case DRC_STEPSIZE:
-	    if (cmd->tx_argc == 3)
+	    if (argc == 3)
 	    {
-		DRCStepSize = atoi(cmd->tx_argv[2]);
-		TxPrintf("DRC step size is now %d lambda)\n", DRCStepSize);
+		DRCStepSize = cmdScaleCoord(w, argv[2], FALSE, TRUE);
+		DRCStepSize *= DRCCurStyle->DRCScaleFactor;
+		TxPrintf("DRC step size is now %d units)\n",
+				DRCStepSize / DRCCurStyle->DRCScaleFactor);
 	    }
 	    else
 	    {
-		TxPrintf("DRC step size is %d lambda\n", DRCStepSize);
-		if (DRCStepSize != (16 * MaxHalo))
-		    TxPrintf("Recommended step size is %d lambda\n", 16 * MaxHalo);
+		TxPrintf("DRC step size is %d units\n",
+			DRCStepSize / DRCCurStyle->DRCScaleFactor);
+		if (DRCStepSize != (16 * DRCCurStyle->DRCTechHalo))
+		    TxPrintf("Recommended step size is %d units\n",
+				(16 * DRCCurStyle->DRCTechHalo) /
+				DRCCurStyle->DRCScaleFactor);
 	    }
 	    break;
 
@@ -3452,7 +3643,7 @@ default_action:
 	childPoint = def->cd_bbox.r_ll;
     if (!hasRoot)
     {
-	if (!ToolGetBox(&rootDef, &rootBox) || (rootDef != EditRootDef))
+	if (!ToolGetBox(&rootDef, &rootBox))
 	{
 box_error:
 	    TxError("The box's lower-left corner must point to the place\n");
@@ -3460,6 +3651,12 @@ box_error:
 		cmd->tx_argv[1]);
 	    return FALSE;
 	}
+	else if (rootDef != EditRootDef)
+	{
+	    TxError("The box is in cell \"%s\", not in the edit cell \"%s\"\n",
+			rootDef->cd_name, EditRootDef->cd_name);
+	    return FALSE;
+	}
 	rootPoint = rootBox.r_ll;
     }
     if (!hasTrans)
