@@ -698,6 +698,10 @@ again:
 	newName = newname;
     }
 
+    /* Remove any ".mag" file extension from the name */
+    else if (!strcmp(newName + strlen(newName) - 4, ".mag"))
+	*(newName + strlen(newName) - 4) = '\0';
+
     if (strcmp(newName, def->cd_name) != 0)
     {
 	if (f = PaOpen(newName, "r", DBSuffix, ".", (char *) NULL, &filename))
