@@ -1521,6 +1521,72 @@ dbTileScaleFunc(tile, scvals)
     return 0;
 }
 
+/*
+ * ----------------------------------------------------------------------------
+ *
+ * DBSrCellUses --
+ *
+ *   Do function "func" for each cell use in cellDef, passing "arg" as
+ *   client data.  Unlike DBEnumCell, this routine first collects a linked
+ *   list of cell uses, then performs the function on the list, so that
+ *   the search cannot be corrupted by, removing or reallocating the use
+ *   structure from the cell def.  Function "func" takes 2 arguments:
+ *
+ *	int func(Celluse *use, ClientData arg) {}
+ *
+ * Results:
+ *	0 one successful completion of the search, 1 on error.
+ *
+ * Side Effects:
+ *	Whatever "func" does.
+ *
+ * ----------------------------------------------------------------------------
+ */
+
+int
+DBSrCellUses(cellDef, func, arg)
+    CellDef *cellDef;	/* Pointer to CellDef to search for uses. */
+    int (*func)();	/* Function to apply for each cell use.	  */
+    ClientData arg;	/* data to be passed to function func().  */
+{
+    int dbCellUseEnumFunc();
+    int retval;
+    CellUse *use;
+    LinkedCellUse *luhead, *lu;
+
+    /* DBCellEnum() attempts to read unavailable celldefs.  We don't	*/
+    /* want to do that here, so check CDAVAILABLE flag first.	  	*/
+
+    if ((cellDef->cd_flags & CDAVAILABLE) == 0) return 0;
+
+    /* Enumerate all unique cell uses, and scale their position,	*/
+    /* transform, and array information.				*/
+
+    luhead = NULL;
+
+    retval = DBCellEnum(cellDef, dbCellUseEnumFunc, (ClientData) &luhead);
+
+    lu = luhead;
+    while (lu != NULL)
+    {
+	use = lu->cellUse;
+	if ((*func)(use, arg)) {
+	   retval = 1;
+	   break;
+	}
+	lu = lu->cu_next;
+    }
+
+    /* Free this linked cellUse structure */
+    lu = luhead;
+    while (lu != NULL)
+    {
+	freeMagic((char *)lu);
+	lu = lu->cu_next;
+    }
+    return retval;
+}
+
 /*
  * ----------------------------------------------------------------------------
  *
