@@ -17,11 +17,12 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Header: /ufs/repository/magic/database/DBcellsubr.c,v 1.2 2001/01/12 22:12:20 jsolomon Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/database/DBcellsubr.c,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/malloc.h"
 #include "utils/hash.h"
 #include "utils/utils.h"
@@ -29,11 +30,59 @@ static char rcsid[] = "$Header: /ufs/repository/magic/database/DBcellsubr.c,v 1.
 #include "tiles/tile.h"
 #include "database/database.h"
 #include "database/databaseInt.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 
     /* Forward declarations */
 extern void dbSetPlaneTile();
-
+
+/*
+ * ----------------------------------------------------------------------------
+ * DBDescendSubcell --
+ *
+ * Determine from the supplied mask if a tree search should descend into
+ * a cell.  Note that the mask must be one of the following:  1) a single
+ * bit representing a window dbw_bitmask, 2) CU_DESCEND_ALL (== 0), or
+ * 3) a number that is not a power of two that is defined in database.h
+ * as a valid type for xMask (e.g., CU_DESCEND_SPECIAL).
+ *
+ * Results:
+ *	TRUE if we should descend, FALSE if not.
+ *
+ * Side effects:
+ * 	None.
+ *
+ * Notes:
+ *	This routine can be expanded as necessary, adding flags for various
+ *	modes of determining whether or not to descend into a subcell.
+ *
+ * ----------------------------------------------------------------------------
+ */
+
+bool
+DBDescendSubcell(use, xMask)
+    CellUse *use;
+    unsigned int xMask;
+{
+    /* Check single bit (window ID) or zero */
+    if (((xMask - 1) & xMask) == 0)
+	return ((use->cu_expandMask & xMask) == xMask);
+
+    else switch (xMask) {
+	case CU_DESCEND_SPECIAL:
+	    return (use->cu_expandMask == CU_DESCEND_SPECIAL);
+
+	case CU_DESCEND_NO_SUBCKT:
+	    if ((use->cu_def->cd_flags & CDAVAILABLE) == 0)
+		if (!DBCellRead(use->cu_def, (char *) NULL, TRUE))
+		    return FALSE;
+	    return (DBIsSubcircuit(use->cu_def)) ? FALSE : TRUE;
+
+	case CU_DESCEND_NO_VENDOR:
+	    return (use->cu_def->cd_flags & CDVENDORGDS) ? FALSE : TRUE;
+    }
+    return TRUE;	/* in case CU_DESCEND_ALL is not defined as 0 */
+}
+
 /*
  * ----------------------------------------------------------------------------
  *
