@@ -301,7 +301,7 @@ dbSrConnectFunc(tile, csa)
     int i;
     TileTypeBitMask *connectMask;
     TileType loctype, checktype;
-    unsigned int planes;
+    PlaneMask planes;
 
     TiToRect(tile, &tileArea);
 
@@ -695,9 +695,13 @@ dbcConnectFunc(tile, cx)
 
 	TTMaskSetOnlyType(&notConnectMask, loctype);
 
-	/* Differenct contact types may share residues (6/18/04) */
+	/* Different contact types may share residues (6/18/04) */
+	/* Use TTMaskIntersect(), not TTMaskEqual()---types	*/
+	/* which otherwise stack may be in separate cells	*/
+	/* (12/1/05)						*/
+
 	for (ctype = TT_TECHDEPBASE; ctype < DBNumUserLayers; ctype++)
-	    if (TTMaskEqual(rMask, DBResidueMask(ctype)))
+	    if (TTMaskIntersect(rMask, DBResidueMask(ctype)))
 		TTMaskSetType(&notConnectMask, ctype);
 
 	/* The mask of contact types must include all stacked contacts */
