@@ -2285,14 +2285,14 @@ DBCellWrite(cellDef, fileName)
      */
     if (tmpf = fopen(tmpname, "w"))
     {
-	/* mkstemp() generates a file with permissions 0600 */
-	/* We want instead to respect the user's umask	    */
-	/* value so the .mag file gets the write	    */
-	/* permissions when doing rename().		    */
+	/* mkstemp() generates a file with permissions 0600.   	*/
+	/* We want instead to respect the user's umask value	*/
+	/* so that the final and original .mag files have the	*/
+	/* same permissions.					*/
 
 	mode_t userumask = umask((mode_t)0);
 	umask(userumask);
-	chmod(tmpname, (mode_t)0666 & ~userumask);
+	fchmod(fileno(tmpf), (mode_t)0666 & ~userumask);
 
 	result = DBCellWriteFile(cellDef, tmpf);
 	(void) fclose(tmpf);
