@@ -349,7 +349,8 @@ dbTechAddOneStackedContact(type1, type2)
 
     /* Contacts do not stack if they share more than one plane */
     /* if (lim->l_pmask == lin->l_pmask) return -1; */
-    if (((lim->l_pmask & lin->l_pmask) & ((lim->l_pmask & lin->l_pmask) - 1)) != 0)
+    if (((lim->l_pmask & lin->l_pmask) & ((lim->l_pmask & lin->l_pmask) - 1))
+		!= 0)
 	return -1;
 
     TTMaskAndMask3(&ttshared, &lim->l_residues, &lin->l_residues);
