@@ -47,9 +47,9 @@ char *DBTechDescription = 0;
 /* Connectivity */
 TileTypeBitMask	 DBConnectTbl[NT];
 TileTypeBitMask	 DBNotConnectTbl[NT];
-unsigned int	 DBConnPlanes[NT];
-unsigned int	 DBAllConnPlanes[NT];
-
+PlaneMask	 DBConnPlanes[NT];
+PlaneMask	 DBAllConnPlanes[NT];
+
 /*
  * ----------------------------------------------------------------------------
  *
