@@ -17,12 +17,13 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Header: /ufs/repository/magic/database/DBtimestmp.c,v 1.2 2001/01/12 22:12:22 jsolomon Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/database/DBtimestmp.c,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
 #include <sys/types.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
@@ -31,7 +32,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/database/DBtimestmp.c,v 1.
 #include "windows/windows.h"
 #include "textio/textio.h"
 #include "drc/drc.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "utils/malloc.h"
 
 /* Overall comments:
