@@ -20,12 +20,12 @@
  */
 
 #ifndef	lint
-static char rcsid[] = "$Header: /ufs/repository/magic/drc/DRCarray.c,v 1.3 2001/04/13 20:02:59 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/drc/DRCarray.c,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $";
 #endif	/* not lint */
 
 #include <sys/types.h>
 #include <stdio.h>
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
@@ -43,9 +43,12 @@ extern int drcArrayYankFunc(), drcArrayOverlapFunc();
  */
 
 static DRCCookie drcArrayCookie = {
-    0, { 0 }, { 0 }, (DRCCookie *) NULL,
+    0, 0, 0, 0,
+    { 0 }, { 0 },
+    0, 0,
     "This layer can't abut or partially overlap between array elements",
-    0, 0, 0};
+    (DRCCookie *) NULL
+};
 
 /* Static variables used to pass information between DRCArrayCheck
  * and drcArrayFunc:
@@ -137,11 +140,11 @@ drcArrayFunc(scx, area)
     tmp.r_xbot = 0;
     tmp.r_ybot = 0;
     if (use->cu_xlo == use->cu_xhi)
-	tmp.r_xtop = TechHalo + use->cu_def->cd_bbox.r_xtop
+	tmp.r_xtop = DRCTechHalo + use->cu_def->cd_bbox.r_xtop
 	    - use->cu_def->cd_bbox.r_xbot;
     else tmp.r_xtop = use->cu_xsep;
     if (use->cu_ylo == use->cu_yhi)
-	tmp.r_ytop = TechHalo + use->cu_def->cd_bbox.r_ytop
+	tmp.r_ytop = DRCTechHalo + use->cu_def->cd_bbox.r_ytop
 	    - use->cu_def->cd_bbox.r_ybot;
     else tmp.r_ytop = use->cu_ysep;
     GeoTransRect(&use->cu_transform, &tmp, &tmp2);
@@ -157,18 +160,18 @@ drcArrayFunc(scx, area)
      * that direction or if the instances are widely spaced.
      */
     
-    if (ysep < ysize + TechHalo)
+    if (ysep < ysize + DRCTechHalo)
     {
 	/* A */
 
 	errorArea.r_xbot = use->cu_bbox.r_xbot;
-	errorArea.r_xtop = use->cu_bbox.r_xbot + xsize + TechHalo;
-	errorArea.r_ybot = use->cu_bbox.r_ybot + ysep - TechHalo;
-	errorArea.r_ytop = use->cu_bbox.r_ybot + ysize + TechHalo;
+	errorArea.r_xtop = use->cu_bbox.r_xbot + xsize + DRCTechHalo;
+	errorArea.r_ybot = use->cu_bbox.r_ybot + ysep - DRCTechHalo;
+	errorArea.r_ytop = use->cu_bbox.r_ybot + ysize + DRCTechHalo;
 	GeoClip(&errorArea, area);
 	if (!GEO_RECTNULL(&errorArea))
 	{
-	    GEO_EXPAND(&errorArea, TechHalo, &yankArea);
+	    GEO_EXPAND(&errorArea, DRCTechHalo, &yankArea);
 	    DBCellClearDef(DRCdef);
 	    (void) DBArraySr(use, &yankArea, drcArrayYankFunc,
 		(ClientData) &yankArea);
@@ -181,11 +184,11 @@ drcArrayFunc(scx, area)
 	/* C */
 
 	errorArea.r_xtop = use->cu_bbox.r_xtop;
-	errorArea.r_xbot = use->cu_bbox.r_xtop - TechHalo;
+	errorArea.r_xbot = use->cu_bbox.r_xtop - DRCTechHalo;
 	GeoClip(&errorArea, area);
 	if (!GEO_RECTNULL(&errorArea))
 	{
-	    GEO_EXPAND(&errorArea, TechHalo, &yankArea);
+	    GEO_EXPAND(&errorArea, DRCTechHalo, &yankArea);
 	    DBCellClearDef(DRCdef);
 	    (void) DBArraySr(use, &yankArea, drcArrayYankFunc,
 		(ClientData) &yankArea);
@@ -196,18 +199,18 @@ drcArrayFunc(scx, area)
 	}
     }
 
-    if (xsep < xsize + TechHalo)
+    if (xsep < xsize + DRCTechHalo)
     {
 	/* B */
 
-	errorArea.r_xbot = use->cu_bbox.r_xbot + xsep - TechHalo;
-	errorArea.r_xtop = use->cu_bbox.r_xbot + xsize + TechHalo;
+	errorArea.r_xbot = use->cu_bbox.r_xbot + xsep - DRCTechHalo;
+	errorArea.r_xtop = use->cu_bbox.r_xbot + xsize + DRCTechHalo;
 	errorArea.r_ybot = use->cu_bbox.r_ybot;
-	errorArea.r_ytop = errorArea.r_ybot + ysep - TechHalo;
+	errorArea.r_ytop = errorArea.r_ybot + ysep - DRCTechHalo;
 	GeoClip(&errorArea, area);
 	if (!GEO_RECTNULL(&errorArea))
 	{
-	    GEO_EXPAND(&errorArea, TechHalo, &yankArea);
+	    GEO_EXPAND(&errorArea, DRCTechHalo, &yankArea);
 	    DBCellClearDef(DRCdef);
 	    (void) DBArraySr(use, &yankArea, drcArrayYankFunc,
 		(ClientData) &yankArea);
@@ -220,11 +223,11 @@ drcArrayFunc(scx, area)
 	/* D */
 
 	errorArea.r_ytop = use->cu_bbox.r_ytop;
-	errorArea.r_ybot = use->cu_bbox.r_ytop - TechHalo;
+	errorArea.r_ybot = use->cu_bbox.r_ytop - DRCTechHalo;
 	GeoClip(&errorArea, area);
 	if (!GEO_RECTNULL(&errorArea))
 	{
-	    GEO_EXPAND(&errorArea, TechHalo, &yankArea);
+	    GEO_EXPAND(&errorArea, DRCTechHalo, &yankArea);
 	    DBCellClearDef(DRCdef);
 	    (void) DBArraySr(use, &yankArea, drcArrayYankFunc,
 		(ClientData) &yankArea);
@@ -293,11 +296,15 @@ DRCArrayCheck(def, area, func, cdarg)
      * illegal overlaps.
      */
 
+/*
     savedPaintTable = DBNewPaintTable(DRCPaintTable);
     savedPaintPlane = DBNewPaintPlane(DBPaintPlaneMergeOnce);
+*/
     (void) DBCellSrArea(&scx, drcArrayFunc, (ClientData) area);
+/*
     (void) DBNewPaintTable(savedPaintTable);
     (void) DBNewPaintPlane(savedPaintPlane);
+*/
 
     /* Update count of array tiles processed. */
 
@@ -378,7 +385,7 @@ drcArrayOverlapFunc(use, transform, x, y, arg)
     GeoTransRect(&tinv, arg->dCD_clip, &scx.scx_area);
     scx.scx_use = use;
     scx.scx_trans = *transform;
-    (void) DBTreeSrTiles(&scx, &DRCExactOverlapTypes, 0,
+    (void) DBTreeSrTiles(&scx, &DRCCurStyle->DRCExactOverlapTypes, 0,
 	drcExactOverlapTile, (ClientData) arg);
     return 0;
 }
