@@ -41,9 +41,12 @@ int dbDRCDebug = 0;
  */
 
 static DRCCookie drcOverlapCookie = {
-    0, { 0 }, { 0 }, (DRCCookie *) NULL,
+    0, 0, 0, 0,
+    { 0 }, { 0 },
+    0, 0,
     "Can't overlap those layers",
-    0, 0, 0};
+    (DRCCookie *) NULL
+};
 
 /* Forward references: */
 
@@ -203,7 +206,9 @@ DRCBasicCheck (celldef, checkRect, clipRect, function, cdata)
     int	errors;
     int planeNum;
 
-		/*  Insist on top quality rectangles. */
+    if (DRCCurStyle == NULL) return 0;	/* No DRC, no errors */
+
+    /*  Insist on top quality rectangles. */
 
     if ((checkRect->r_xbot >= checkRect->r_xtop)
 	    || (checkRect->r_ybot >= checkRect->r_ytop))
@@ -221,15 +226,10 @@ DRCBasicCheck (celldef, checkRect, clipRect, function, cdata)
     for (planeNum = PL_TECHDEPBASE; planeNum < DBNumPlanes; planeNum++)
     {
         arg.dCD_plane = planeNum;
-#ifdef	DRC_EXTENSIONS
 	DBResetTilePlane(celldef->cd_planes[planeNum], DRC_UNPROCESSED);
-#endif
         (void) DBSrPaintArea ((Tile *) NULL, celldef->cd_planes[planeNum],
 		checkRect, &DBAllTypeBits, drcTile, (ClientData) &arg);
     }
-#ifdef	DRC_CIF_EXTENSIONS
-    drcCifCheck(&arg);
-#endif
     return (errors);
 }
 
@@ -265,7 +265,7 @@ drcTile (tile, arg)
     TileTypeBitMask tmpMask, *rMask;
     unsigned char stackpending = (char)0;
     bool triggered, trigpending;	/* Hack for widespacing rule */
-    int cdist, ccdist, result;
+    int cdist, dist, ccdist, result;
 
     arg->dCD_constraint = &errRect;
     arg->dCD_radial = 0; 
@@ -332,8 +332,7 @@ drcTile (tile, arg)
 
     if (LEFT(tile) >= rect->r_xbot)		/* check tile against rect */
     {
-	Tile *tpleft;
-	Tile *tpl, *tpr;
+	Tile *tpleft, *tpl, *tpr;
 	TileType tt, to;
 	int edgeTop, edgeBot;
         int top = MIN(TOP(tile), rect->r_ytop);
@@ -406,9 +405,11 @@ drcTile (tile, arg)
 		if (stackpending && (to == tt)) goto hnextstacktype;
 		
 		triggered = FALSE;
-		for (cptr = DRCRulesTbl[to][tt]; cptr != (DRCCookie *) NULL;
+		for (cptr = DRCCurStyle->DRCRulesTbl[to][tt]; cptr != (DRCCookie *) NULL;
 			cptr = cptr->drcc_next)
 		{
+		    /* Find the rule distances according to the scale factor */
+		    dist = cptr->drcc_dist;
 		    cdist = cptr->drcc_cdist;
 		    trigpending = (cptr->drcc_flags & DRC_TRIGGER) ? TRUE : FALSE;
 
@@ -447,7 +448,6 @@ drcTile (tile, arg)
 			errRect.r_ybot = edgeBot;
 		    }
 
-#ifdef DRC_EXTENSIONS
 		    if (cptr->drcc_flags & DRC_AREA)
 		    {
 			drcCheckArea(tile,arg,cptr);
@@ -459,20 +459,6 @@ drcTile (tile, arg)
 			/* New algorithm --- Tim 3/6/05 */
 			Rect *lr;
 
-			/* Fix (3/13/06):  "maxwidth" rule requires searching	*/
-			/* for areas > than the given maximum, not >=.  To	*/
-			/* find areas of width strictly greater than the	*/
-			/* maximum, we need to add 1 to the rule's distance.	*/
-			/* But this has to be 1 internal unit.  If we add 1	*/
-			/* when we parse the techfile, we will hard-code the	*/
-			/* meaning of 1 internal unit, and we will get an	*/
-			/* incorrect distance if we change the grid scale.  So	*/
-			/* we add 1 (true) internal unit here.  Note that this	*/
-			/* correction is valid ONLY for the new algorithm, and	*/
-			/* only for the "maxwidth" rule itself, not for the	*/
-			/* "widespacing" rule when "maxwidth" is used as a	*/
-			/* trigger rule.					*/
-
 		        if (!trigpending) cptr->drcc_dist++;
 
 			if (cptr->drcc_flags & DRC_REVERSE)
@@ -518,7 +504,6 @@ drcTile (tile, arg)
 			    drcCheckRectSize(tile, arg, cptr);
 			continue;
 		    }
-#endif
 
 		    if (cptr->drcc_flags & DRC_REVERSE)
 		    {
@@ -535,9 +520,9 @@ drcTile (tile, arg)
 			    for (tpl = LB(tpleft); RIGHT(tpl) < edgeX; tpl = TR(tpl));
 			else tpl = tpleft;
 
-			/* Make sure the edge actually stops at edgeBot */
-			if ( (TiGetTopType(tpl) != TiGetBottomType(tpleft)) ||
-			     (TiGetTopType(tpr) != TiGetBottomType(tile)) )
+			/* Make sure the edge stops at edgeBot */
+			if ((TiGetTopType(tpl) != TiGetBottomType(tpleft)) ||
+				(TiGetTopType(tpr) != TiGetBottomType(tile)))
 			{
 			    if (TTMaskHasType(&cptr->drcc_corner, TiGetTopType(tpr)))
 		 	    {
@@ -550,7 +535,7 @@ drcTile (tile, arg)
 			if (cptr->drcc_flags & DRC_BOTHCORNERS)
 			{
 			    /*
-			     * Check the other corner.
+			     * Check the other corner
 			     */
 
 			    /* Find point (4) to the top right of pointT */
@@ -562,11 +547,12 @@ drcTile (tile, arg)
 			    if (TOP(tpleft) <= edgeTop) tpl = RT(tpleft);
 			    else tpl = tpleft;
 
-			    /* Make sure the edge actually stops at edgeBot */
-			    if ( (TiGetBottomType(tpl) != TiGetTopType(tpleft)) ||
-				 (TiGetBottomType(tpr) != TiGetTopType(tile)) )
+			    /* Make sure the edge stops at edgeTop */
+			    if ((TiGetBottomType(tpl) != TiGetTopType(tpleft)) ||
+					(TiGetBottomType(tpr) != TiGetTopType(tile)))
 			    {
-				if (TTMaskHasType(&cptr->drcc_corner, TiGetBottomType(tpr)))
+			        if (TTMaskHasType(&cptr->drcc_corner,
+					TiGetBottomType(tpr)))
 				{
 				    errRect.r_ytop = edgeTop + cdist;
 				    if (DRCEuclidean)
@@ -579,7 +565,7 @@ drcTile (tile, arg)
 			 * Just for grins, see if we could avoid a messy search
 			 * by looking only at tpleft.
 			 */
-			errRect.r_xbot = edgeX - cptr->drcc_dist;
+			errRect.r_xbot = edgeX - dist;
 			if (LEFT(tpleft) <= errRect.r_xbot
 				&& BOTTOM(tpleft) <= errRect.r_ybot
 				&& TOP(tpleft) >= errRect.r_ytop
@@ -593,9 +579,7 @@ drcTile (tile, arg)
 			}
 			errRect.r_xtop = edgeX;
 			arg->dCD_initial = tile;
-#ifdef DRC_EXTENSIONS
 			arg->dCD_which = DRC_LEFT;
-#endif
 		    }
 		    else  /* FORWARD */
 		    {
@@ -612,9 +596,9 @@ drcTile (tile, arg)
 			    for (tpr = RT(tile); LEFT(tpr) > edgeX; tpr = BL(tpr));
 			else tpr = tile;
 
-			/* Make sure the edge actually stops at edgeBot */
-			if ( (TiGetBottomType(tpl) != TiGetTopType(tpleft)) ||
-			     (TiGetBottomType(tpr) != TiGetTopType(tile)) )
+			/* Make sure the edge stops at edgeTop */
+			if ((TiGetBottomType(tpl) != TiGetTopType(tpleft)) ||
+				(TiGetBottomType(tpr) != TiGetTopType(tile)))
 			{
 			    if (TTMaskHasType(&cptr->drcc_corner, TiGetBottomType(tpl)))
 			    {
@@ -627,10 +611,10 @@ drcTile (tile, arg)
 			if (cptr->drcc_flags & DRC_BOTHCORNERS)
 			{
 			    /*
-			     * Check the other corner.
+			     * Check the other corner
 			     */
 
-			    /* Find point (2) to the bottom left of pointB */
+			    /* Find point (2) to the bottom left of pointB. */
 			    if (BOTTOM(tpleft) >= edgeBot)
 				for (tpl = LB(tpleft); RIGHT(tpl) < edgeX; tpl = TR(tpl));
 			    else tpl = tpleft;
@@ -639,9 +623,9 @@ drcTile (tile, arg)
 			    if (BOTTOM(tile) >= edgeBot) tpr = LB(tile);
 			    else tpr = tile;
 
-			    /* Make sure the edge actually stops at edgeBot */
-			    if ( (TiGetTopType(tpl) != TiGetBottomType(tpleft)) ||
-				 (TiGetTopType(tpr) != TiGetBottomType(tile)) )
+			    /* Make sure the edge stops at edgeBot */
+			    if ((TiGetTopType(tpl) != TiGetBottomType(tpleft)) ||
+					(TiGetTopType(tpr) != TiGetBottomType(tile)))
 			    {
 				if (TTMaskHasType(&cptr->drcc_corner, TiGetTopType(tpl)))
 				{
@@ -656,7 +640,7 @@ drcTile (tile, arg)
 			 * Just for grins, see if we could avoid a messy search
 			 * by looking only at tile.
 			 */
-			errRect.r_xtop = edgeX + cptr->drcc_dist;
+			errRect.r_xtop = edgeX + dist;
 			if (RIGHT(tile) >= errRect.r_xtop
 				&& BOTTOM(tile) <= errRect.r_ybot
 				&& TOP(tile) >= errRect.r_ytop
@@ -670,9 +654,7 @@ drcTile (tile, arg)
 			}
 			errRect.r_xbot = edgeX;
 			arg->dCD_initial= tpleft;
-#ifdef DRC_EXTENSIONS
 			arg->dCD_which = DRC_RIGHT;
-#endif
 		    }
 		    if (arg->dCD_radial)
 		    {
@@ -782,8 +764,7 @@ checkbottom:
 
     if (BOTTOM(tile) >= rect->r_ybot)
     {
-	Tile *tpbot;
-	Tile *tpx;
+	Tile *tpbot, *tpx;
 	TileType tt, to;
 	int edgeLeft, edgeRight;
         int left = MAX(LEFT(tile), rect->r_xbot);
@@ -857,9 +838,11 @@ checkbottom:
 		if (stackpending && (to == tt)) goto vnextstacktype;
 
 		triggered = FALSE;
-		for (cptr = DRCRulesTbl[to][tt]; cptr != (DRCCookie *) NULL;
+		for (cptr = DRCCurStyle->DRCRulesTbl[to][tt]; cptr != (DRCCookie *) NULL;
 				cptr = cptr->drcc_next)
 		{
+		    /* Find the rule distances according to the scale factor */
+		    dist = cptr->drcc_dist;
 		    cdist = cptr->drcc_cdist;
 		    trigpending = (cptr->drcc_flags & DRC_TRIGGER) ? TRUE : FALSE;
 
@@ -889,7 +872,6 @@ checkbottom:
 
 		    /* top to bottom */
 
-#ifdef DRC_EXTENSIONS
 		    if ((cptr->drcc_flags & (DRC_MAXWIDTH | DRC_BENDS)) ==
 				(DRC_MAXWIDTH | DRC_BENDS))
 		    {
@@ -923,6 +905,7 @@ checkbottom:
 				(*(arg->dCD_errors))++;
 			    }           
 			}
+
 			continue;
 		    }
 		    else if (cptr->drcc_flags & (DRC_AREA|DRC_RECTSIZE|DRC_MAXWIDTH))
@@ -931,7 +914,6 @@ checkbottom:
 			if (trigpending) cptr = cptr->drcc_next;
 			continue;
 		    }
-#endif
 
 		    if (cptr->drcc_flags & DRC_REVERSE)
 		    {
@@ -939,7 +921,6 @@ checkbottom:
 			 * Determine corner extensions.
 			 * Find the point (3) to the top right of pointR
 			 */
-
 			if (RIGHT(tile) <= edgeRight)
 			    for (tpx = TR(tile); BOTTOM(tpx) > edgeY; tpx = LB(tpx));
 			else tpx = tile;
@@ -973,7 +954,7 @@ checkbottom:
 			 * Just for grins, see if we could avoid
 			 * a messy search by looking only at tpbot.
 			 */
-			errRect.r_ybot = edgeY - cptr->drcc_dist;
+			errRect.r_ybot = edgeY - dist;
 			if (BOTTOM(tpbot) <= errRect.r_ybot
 				&& LEFT(tpbot) <= errRect.r_xbot
 				&& RIGHT(tpbot) >= errRect.r_xtop
@@ -987,9 +968,7 @@ checkbottom:
 			}
 			errRect.r_ytop = edgeY;
 			arg->dCD_initial = tile;
-#ifdef DRC_EXTENSIONS
 			arg->dCD_which = DRC_BOTTOM;
-#endif
 		    }
 		    else  /* FORWARD */
 		    {
@@ -1015,7 +994,6 @@ checkbottom:
 			     * Check the other corner by finding the
 			     * point (2) to the bottom right of pointR.
 			     */
-
 			    if (RIGHT(tpbot) <= edgeRight) tpx = TR(tpbot);
 			    else tpx = tpbot;
 
@@ -1031,7 +1009,7 @@ checkbottom:
 			 * Just for grins, see if we could avoid
 			 * a messy search by looking only at tile.
 			 */
-			errRect.r_ytop = edgeY + cptr->drcc_dist;
+			errRect.r_ytop = edgeY + dist;
 			if (TOP(tile) >= errRect.r_ytop
 				&& LEFT(tile) <= errRect.r_xbot
 				&& RIGHT(tile) >= errRect.r_xtop
@@ -1045,9 +1023,7 @@ checkbottom:
 			}
 			errRect.r_ybot = edgeY;
 			arg->dCD_initial = tpbot;
-#ifdef DRC_EXTENSIONS
 			arg->dCD_which = DRC_TOP;
-#endif
 		    }
 		    if (arg->dCD_radial)
 		    {
