@@ -82,8 +82,6 @@ global bool DRCEuclidean = FALSE;
  * when DRCInit() is called.
  */
 
-global int DRCStepSize = 0;
-
 /*------- Things used by other DRC modules but not outside world. -------*/
 
 /* Base of linked list of CellDefs waiting for background DRC.
@@ -237,7 +235,7 @@ DRCCheckThis (celldef, operation, area)
 
     if (area != (Rect *) NULL)
     {
-	GEO_EXPAND(area, TechHalo, &dummyRect);
+	GEO_EXPAND(area, DRCTechHalo, &dummyRect);
 
 	SigDisableInterrupts();
 	DBPaintPlane(celldef->cd_planes[PL_DRC_CHECK], &dummyRect,
@@ -316,31 +314,6 @@ DRCRemovePending(def)
     }
 }
 
-/*
- * ----------------------------------------------------------------------------
- *
- * DRCPreInit --
- *
- *	Initialization stuff that has to come before TechLoad() when
- *	magic starts up.
- *
- * Results:
- *	None.
- *
- * Side effects:
- *	None (memory should be nulled; this is a safeguard.)
- *
- * ----------------------------------------------------------------------------
- */
-
-void
-DRCPreInit()
-{
-    /* Make sure that the rule tables are initialized to NULL */
-
-    drcInitRulesTbl();
-}
-
 /*
  * ----------------------------------------------------------------------------
  *
@@ -399,19 +372,6 @@ DRCInit()
     DRCDisplayCheckTiles = TTMaskHasType(&displayedTypes, TT_CHECKPAINT)
 			|| TTMaskHasType(&displayedTypes, TT_CHECKSUBCELL);
 
-    /* A reasonable chunk size for design-rule checking is about
-     * 16 times the maximum design-rule interaction distance.  This
-     * results in a halo overhead of about 27%.  If there's no DRC
-     * information at all (TechHalo is zero), just pick any size.
-     * Don't set it if it was already given explicitly in the tech
-     * file, though.
-     */
-    if (DRCStepSize == 0)
-    {
-	if (TechHalo == 0) DRCStepSize = 64;
-	else DRCStepSize = 16 * TechHalo;
-    }
-
     /* Initialize mask of DRC layer types. */
 
     TTMaskZero(&DRCLayers);
@@ -426,7 +386,6 @@ DRCInit()
     drcDisplayPlane = DBNewPlane((ClientData) TT_SPACE);
     drcTempPlane = DBNewPlane((ClientData) TT_SPACE);
 }
-
 
 #ifdef MAGIC_WRAPPER
 /* Needs to be global so the DRCBreak() routine can use the value */
@@ -687,7 +646,7 @@ drcCheckTile(tile, arg)
      * erasebox.
      */
 
-    GEO_EXPAND(&erasebox, TechHalo, &checkbox);
+    GEO_EXPAND(&erasebox, DRCTechHalo, &checkbox);
 
     /* Use drcDisplayPlane to save all the current errors in the
      * area we're about to recheck.
