@@ -18,8 +18,6 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/drc/
 #include "utils/signals.h"
 #include "utils/stack.h"
 
-#ifdef DRC_EXTENSIONS
-
 Stack *DRCstack = (Stack *)NULL;
 
 #define PUSHTILE(tp) \
@@ -48,11 +46,13 @@ drcCheckArea(starttile,arg,cptr)
 	DRCCookie	*cptr;
 
 {
-     int		arealimit = cptr->drcc_cdist;
-     int		area=0;
-     TileTypeBitMask	*oktypes = &cptr->drcc_mask;
-     Tile		*tile,*tp;
-     Rect		*cliprect = arg->dCD_rect;
+    int			arealimit;
+    int			area=0;
+    TileTypeBitMask	*oktypes = &cptr->drcc_mask;
+    Tile		*tile,*tp;
+    Rect		*cliprect = arg->dCD_rect;
+
+    arealimit = cptr->drcc_cdist;
      
     arg->dCD_cptr = cptr;
     if (DRCstack == (Stack *) NULL)
@@ -63,7 +63,6 @@ drcCheckArea(starttile,arg,cptr)
 
     while (!StackEmpty(DRCstack))
     {
-	tile = (Tile *) STACKPOP(DRCstack);
 	if (tile->ti_client != (ClientData)DRC_PENDING) continue;
 	area += (RIGHT(tile)-LEFT(tile))*(TOP(tile)-BOTTOM(tile));
 	tile->ti_client = (ClientData)DRC_PROCESSED;
@@ -91,6 +90,7 @@ drcCheckArea(starttile,arg,cptr)
 	for (tp = TR(tile); TOP(tp) > BOTTOM(tile); tp = LB(tp))
 	    if (TTMaskHasType(oktypes, TiGetLeftType(tp))) PUSHTILE(tp);
      }
+
      if (area < arealimit)
      {
 	 Rect	rect;
@@ -198,12 +198,12 @@ drcCheckMaxwidth(starttile,arg,cptr)
     {
 	tile = (Tile *) STACKPOP(DRCstack);
 	if (tile->ti_client != (ClientData)DRC_PENDING) continue;
+	tile->ti_client = (ClientData)DRC_PROCESSED;
 	
 	if (boundrect.r_xbot > LEFT(tile)) boundrect.r_xbot = LEFT(tile);
 	if (boundrect.r_xtop < RIGHT(tile)) boundrect.r_xtop = RIGHT(tile);
 	if (boundrect.r_ybot > BOTTOM(tile)) boundrect.r_ybot = BOTTOM(tile);
 	if (boundrect.r_ytop < TOP(tile)) boundrect.r_ytop = TOP(tile);
-	tile->ti_client = (ClientData)DRC_PROCESSED;
 
         if (boundrect.r_xtop - boundrect.r_xbot > edgelimit &&
              boundrect.r_ytop - boundrect.r_ybot > edgelimit)
@@ -243,6 +243,7 @@ drcCheckMaxwidth(starttile,arg,cptr)
 	}
 	 
     }
+
     /* reset the tiles */
     starttile->ti_client = (ClientData)DRC_UNPROCESSED;
     STACKPUSH(starttile, DRCstack);
@@ -308,8 +309,7 @@ drcCheckRectSize(starttile, arg, cptr)
     struct drcClientData *arg;
     DRCCookie *cptr;
 {
-    int maxsize = cptr->drcc_dist;
-    int even = cptr->drcc_cdist;
+    int maxsize, even;
     TileTypeBitMask *oktypes = &cptr->drcc_mask;
     int width;
     int height;
@@ -318,6 +318,9 @@ drcCheckRectSize(starttile, arg, cptr)
     Tile *t;
     bool error = FALSE;
 
+    maxsize = cptr->drcc_dist;
+    even = cptr->drcc_cdist;
+
     /* This code only has to work for rectangular regions, since we always
      * check for rectangular-ness using normal edge rules produced when
      * we read in the tech file.
@@ -569,5 +572,3 @@ findMaxRects(tile, mrd)
     else
 	return 1;	/* no more max size areas; stop the search */
 }
-
-#endif
