@@ -49,6 +49,14 @@ extern void TxError(char *, ...);
  * variables.
  */
 
+/* The following points to a list of all the DRC styles currently
+ * understood:
+ */
+
+DRCKeep *DRCStyleList = NULL;
+
+DRCStyle *DRCCurStyle = NULL;
+
 /* Used by both routines: */
 
 int DRCErrorCount;		/* Incremented by each call to either routine.
@@ -367,7 +375,7 @@ drcWhyFunc(scx, cdarg)
 
     /* Check paint and interactions in this subcell. */
     
-    GEO_EXPAND(&scx->scx_area, TechHalo, &haloArea);
+    GEO_EXPAND(&scx->scx_area, DRCTechHalo, &haloArea);
     (void) DRCBasicCheck(def, &haloArea, &scx->scx_area,
 	drcPrintError, (ClientData) &scx->scx_area);
     (void) DRCInteractionCheck(def, &scx->scx_area,
@@ -439,7 +447,7 @@ drcCheckFunc(scx, cdarg)
     cellArea = scx->scx_area;
     def = scx->scx_use->cu_def;
     GeoClip(&cellArea, &def->cd_bbox);
-    GEO_EXPAND(&cellArea, TechHalo, &cellArea);
+    GEO_EXPAND(&cellArea, DRCTechHalo, &cellArea);
 
     DBPaintPlane(def->cd_planes[PL_DRC_CHECK], &cellArea,
 		DBStdPaintTbl(TT_CHECKPAINT, PL_DRC_CHECK),
