@@ -19,12 +19,13 @@
  */
 
 #ifndef	lint
-static char rcsid[] = "$Header: /ufs/repository/magic/drc/DRCsubcell.c,v 1.2 2001/01/12 22:12:29 jsolomon Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/drc/DRCsubcell.c,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $";
 #endif	/* not lint */
 
 #include <stdio.h>
 #include <sys/types.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "textio/textio.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
@@ -33,7 +34,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/drc/DRCsubcell.c,v 1.2 200
 #include "drc/drc.h"
 #include "windows/windows.h"
 #include "commands/commands.h"
-#include "undo/undo.h"
+#include "utils/undo.h"
 
 /* The variables below are made owns so that they can be used to
  * pass information to the various search functions.
@@ -55,9 +56,12 @@ static ClientData drcSubClientData;
  */
 
 static DRCCookie drcSubcellCookie = {
-    0, { 0 }, { 0 }, (DRCCookie *) NULL,
+    0, 0, 0, 0,
+    { 0 }, { 0 },
+    0, 0,
     "This layer can't abut or partially overlap between subcells",
-    0, 0, 0};
+    (DRCCookie *) NULL
+};
 
 
 /*
@@ -103,7 +107,7 @@ drcFindOtherCells(tile, area)
  * drcSubcellTileFunc --
  *
  * 	Called by TiSrArea when looking for interactions in
- *	a given area.  It sees if this subcell tell participates
+ *	a given area.  It sees if this subcell tile participates
  *	in any interactions in the area we're rechecking.
  *
  * Results:
@@ -348,8 +352,6 @@ drcExactOverlapCheck(tile, arg)
     Rect rect;
 
     TiToRect(tile, &rect);
-    if (GEO_SURROUND(arg->dCD_rect, &rect)) return 0;
-
     GeoClip(&rect, arg->dCD_clip);
     if (GEO_RECTNULL(&rect)) return 0;
 
@@ -392,20 +394,94 @@ drcExactOverlapTile(tile, cxp)
 				 */
 {
     struct drcClientData *arg;
-    TileTypeBitMask typeMask;
-    Rect r1, r2;
+    TileTypeBitMask typeMask, invMask;
+    TileType type, t;
+    Tile *tp;
+    Rect r1, r2, r3, rex;
     int i;
     
     arg = (struct drcClientData *) cxp->tc_filter->tf_arg;
     TiToRect(tile, &r1);
     GeoTransRect(&(cxp->tc_scx->scx_trans), &r1, &r2);
-    arg->dCD_rect = &r2;
-    GEO_EXPAND(&r2, 1, &r1);
+
+    GEO_EXPAND(&r2, 1, &rex); 	/* Area includes abutting tiles */
+    GeoClip(&rex, arg->dCD_clip);	/* Except areas outside search area */
+
+    type = TiGetType(tile);
+    TTMaskSetOnlyType(&typeMask, type);
+    for (t = DBNumUserLayers; t < DBNumTypes; t++)
+	if (TTMaskHasType(DBResidueMask(t), type))
+	    TTMaskSetType(&typeMask, t);
+    TTMaskCom2(&invMask, &typeMask);
+
     for (i = PL_TECHDEPBASE; i < DBNumPlanes; i++)
     {
-	TTMaskSetOnlyType(&typeMask, TiGetType(tile));
-        (void) DBSrPaintArea((Tile *) NULL, DRCdef->cd_planes[i],
-	    &r1, &typeMask, drcExactOverlapCheck, (ClientData) arg);
+        if (DBSrPaintArea((Tile *) NULL, DRCdef->cd_planes[i],
+	    &rex, &typeMask, drcAlwaysOne, (ClientData) NULL))
+	{
+	    /* There is an overlap or abutment of ExactOverlap types. */
+	    /* 1) Check if any invalid type is under this tile.	*/
+
+	    arg->dCD_rect = &r2;
+	    DBSrPaintArea((Tile *) NULL, DRCdef->cd_planes[i], &r2,
+			&invMask, drcExactOverlapCheck, (ClientData) arg);
+
+	    /* 2) Search the neighboring tiles for types that do not	*/
+	    /* match the exact overlap type, and flag abutment errors.	*/
+
+	    /* Search bottom */
+	    arg->dCD_rect = &r3;
+	    for (tp = LB(tile); LEFT(tp) < RIGHT(tile); tp = TR(tp))
+		if (TTMaskHasType(&invMask, TiGetType(tp)))
+		{
+		    TiToRect(tp, &r1);
+		    GeoTransRect(&(cxp->tc_scx->scx_trans), &r1, &r3);
+		    GeoClip(&r3, &rex);
+		    if (!GEO_RECTNULL(&r3))
+			DBSrPaintArea((Tile *) NULL, DRCdef->cd_planes[i],
+				&r3, &typeMask, drcExactOverlapCheck,
+				(ClientData) arg);
+		}
+
+	    /* Search right */
+	    for (tp = TR(tile); TOP(tp) > BOTTOM(tile); tp = LB(tp))
+		if (TTMaskHasType(&invMask, TiGetType(tp)))
+		{
+		    TiToRect(tp, &r1);
+		    GeoTransRect(&(cxp->tc_scx->scx_trans), &r1, &r3);
+		    GeoClip(&r3, &rex);
+		    if (!GEO_RECTNULL(&r3))
+			DBSrPaintArea((Tile *) NULL, DRCdef->cd_planes[i],
+				&r3, &typeMask, drcExactOverlapCheck,
+				(ClientData) arg);
+		}
+
+	    /* Search top */
+	    for (tp = RT(tile); RIGHT(tp) > LEFT(tile); tp = BL(tp))
+		if (TTMaskHasType(&invMask, TiGetType(tp)))
+		{
+		    TiToRect(tp, &r1);
+		    GeoTransRect(&(cxp->tc_scx->scx_trans), &r1, &r3);
+		    GeoClip(&r3, &rex);
+		    if (!GEO_RECTNULL(&r3))
+			DBSrPaintArea((Tile *) NULL, DRCdef->cd_planes[i],
+				&r3, &typeMask, drcExactOverlapCheck,
+				(ClientData) arg);
+		}
+
+	    /* Search left */
+	    for (tp = BL(tile); BOTTOM(tp) < TOP(tile); tp = RT(tp))
+		if (TTMaskHasType(&invMask, TiGetType(tp)))
+		{
+		    TiToRect(tp, &r1);
+		    GeoTransRect(&(cxp->tc_scx->scx_trans), &r1, &r3);
+		    GeoClip(&r3, &rex);
+		    if (!GEO_RECTNULL(&r3))
+			DBSrPaintArea((Tile *) NULL, DRCdef->cd_planes[i],
+				&r3, &typeMask, drcExactOverlapCheck,
+				(ClientData) arg);
+		}
+	}
     }
     return 0;
 }
@@ -455,7 +531,7 @@ DRCInteractionCheck(def, area, func, cdarg)
     int oldTiles, count, x, y;
     Rect intArea, square;
     PaintResultType (*savedPaintTable)[NT][NT];
-    Void (*savedPaintPlane)();
+    void (*savedPaintPlane)();
     struct drcClientData arg;
     SearchContext scx;
 
@@ -483,23 +559,27 @@ DRCInteractionCheck(def, area, func, cdarg)
 	    /* Find all the interactions in the square, and clip to the error
 	     * area we're interested in. */
 
-	    if (!DRCFindInteractions(def, &square, TechHalo, &intArea))
+	    if (!DRCFindInteractions(def, &square, DRCTechHalo, &intArea))
 		continue;
 	    GeoClip(&intArea, area);
     
 	    /* Flatten the interaction area. */
 
 	    DRCstatInteractions += 1;
-	    GEO_EXPAND(&intArea, TechHalo, &scx.scx_area);
+	    GEO_EXPAND(&intArea, DRCTechHalo, &scx.scx_area);
 	    DRCDummyUse->cu_def = def;
 	    scx.scx_use = DRCDummyUse;
 	    scx.scx_trans = GeoIdentityTransform;
 	    DBCellClearDef(DRCdef);
-	    savedPaintTable = DBNewPaintTable(DRCPaintTable);
+/*
+	    savedPaintTable = DBNewPaintTable(DRCCurStyle->DRCPaintTable);
 	    savedPaintPlane = DBNewPaintPlane(DBPaintPlaneMergeOnce);
+*/
 	    (void) DBCellCopyAllPaint(&scx, &DBAllButSpaceBits, 0, DRCuse);
+/*
 	    (void) DBNewPaintTable(savedPaintTable);
 	    (void) DBNewPaintPlane(savedPaintPlane);
+*/
 
 	    /* Run the basic checker over the interaction area. */
 
@@ -521,8 +601,8 @@ DRCInteractionCheck(def, area, func, cdarg)
 	    arg.dCD_cptr = &drcSubcellCookie;
 	    arg.dCD_function = func;
 	    arg.dCD_clientData = cdarg;
-	    (void) DBTreeSrTiles(&scx, &DRCExactOverlapTypes, 0,
-		drcExactOverlapTile, (ClientData) &arg);
+	    (void) DBTreeSrUniqueTiles(&scx, &DRCCurStyle->DRCExactOverlapTypes,
+			0, drcExactOverlapTile, (ClientData) &arg);
 	}
     
     /* Update count of interaction tiles processed. */
@@ -530,8 +610,8 @@ DRCInteractionCheck(def, area, func, cdarg)
     DRCstatIntTiles += DRCstatTiles - oldTiles;
     return count;
 }
-
-int drcFlatCount;
+
+void
 DRCFlatCheck(use, area)
     CellUse *use;
     Rect *area;
@@ -541,9 +621,9 @@ DRCFlatCheck(use, area)
     SearchContext scx;
     void drcIncCount();
     PaintResultType (*savedPaintTable)[NT][NT];
-    Void (*savedPaintPlane)();
+    void (*savedPaintPlane)();
+    int drcFlatCount = 0;
 
-    drcFlatCount = 0;
     UndoDisable();
     for (y = area->r_ybot; y < area->r_ytop;  y += 300)
     {
@@ -555,17 +635,21 @@ DRCFlatCheck(use, area)
 	    chunk.r_ytop = y+300;
 	    if (chunk.r_xtop > area->r_xtop) chunk.r_xtop = area->r_xtop;
 	    if (chunk.r_ytop > area->r_ytop) chunk.r_ytop = area->r_ytop;
-	    GEO_EXPAND(&chunk, TechHalo, &scx.scx_area);
+	    GEO_EXPAND(&chunk, DRCTechHalo, &scx.scx_area);
 	    scx.scx_use = use;
 	    scx.scx_trans = GeoIdentityTransform;
 	    DBCellClearDef(DRCdef);
-	    savedPaintTable = DBNewPaintTable(DRCPaintTable);
+/*
+	    savedPaintTable = DBNewPaintTable(DRCCurStyle->DRCPaintTable);
 	    savedPaintPlane = DBNewPaintPlane(DBPaintPlaneMergeOnce);
+*/
 	    (void) DBCellCopyAllPaint(&scx, &DBAllButSpaceBits, 0, DRCuse);
+/*
 	    (void) DBNewPaintTable(savedPaintTable);
 	    (void) DBNewPaintPlane(savedPaintPlane);
+*/
 	    (void) DRCBasicCheck(DRCdef, &scx.scx_area, &chunk,
-		drcIncCount, (ClientData) NULL);
+		drcIncCount, (ClientData) &drcFlatCount);
 	}
     }
     TxPrintf("%d total errors found.\n", drcFlatCount);
@@ -573,7 +657,11 @@ DRCFlatCheck(use, area)
 }
 
 void
-drcIncCount()
+drcIncCount(def, area, rule, count)
+    CellDef *def;
+    Rect *area;
+    DRCCookie *rule;
+    int *count;
 {
-    drcFlatCount += 1;
+    *count++;
 }
