@@ -29,16 +29,17 @@
 
 typedef struct drccookie
 {
-    int    	       drcc_dist;	/* Extent of rule from edge. */
-    TileTypeBitMask       drcc_mask;	/* Legal types on RHS */
-    TileTypeBitMask       drcc_corner;	/* Types that trigger corner check */
-    struct drccookie * drcc_next;
-    char             * drcc_why;	/* Explanation of error found */
-    int		       drcc_cdist;	/* Size of corner extension. */
-    int		       drcc_flags;	/* Miscellaneous flags, see below. */
-    int		       drcc_plane;	/* Index of plane on which to check
-					 * legal types.
-					 */
+    short    	      drcc_dist;	/* Extent of rule from edge. */
+    unsigned char     drcc_mod;		/* Fractional part of drcc_dist */
+    short	      drcc_cdist;	/* Size of corner extension. */
+    unsigned char     drcc_cmod;	/* Fractional part of drcc_cdist */
+    TileTypeBitMask   drcc_mask;	/* Legal types on RHS */
+    TileTypeBitMask   drcc_corner;	/* Types that trigger corner check */
+    int		      drcc_flags;	/* Miscellaneous flags, see below. */
+    int		      drcc_plane;	/* Index of plane on which to check
+					 * legal types. */
+    char              *drcc_why;	/* Explanation of error found */
+    struct drccookie  *drcc_next;
 } DRCCookie;
 
 /* DRCCookie flags:
@@ -61,20 +62,6 @@ typedef struct drccookie
 #define		DRC_BOTTOM		0x800
 #define		DRC_TRIGGER		0x1000
 
-/*
- * The following are integrated from WRL's code fragments. Since I dont
- * trust my porting that much the code is ifdefed everywhere so that 
- * it can be disabled. -- Stef 96
- *
- * #define DRC_EXTENSIONS if you want the maxwidth, area, and rectangle
- *                         rules
- * #define DRC_CIF_EXTENSIONS if you want the cif rule checking
- *
- * A description of the rules is in doc/
- */
-#define DRC_EXTENSIONS
-#define DRC_CIF_EXTENSIONS
-#ifdef DRC_EXTENSIONS
 #define		DRC_AREA		0x8000
 #define		DRC_MAXWIDTH		0x10000
 #define		DRC_BENDS		0x20000
@@ -84,23 +71,6 @@ typedef struct drccookie
 #define	DRC_PENDING			0
 #define DRC_UNPROCESSED 		MINFINITY
 #define DRC_PROCESSED 			1
-#endif 
-
-#ifdef DRC_CIF_EXTENSIONS
-#ifndef DRC_EXTENSIONS
- err = Cannot_have_drc_cif_extensions_without_the_simple_extensions
-#endif
-#endif
-
-/*
- * Design rule table
- */
-
-extern DRCCookie        *DRCRulesTbl[TT_MAXTYPES][TT_MAXTYPES];
-
-				/*  macro to determine if two TileTypes
-				 *  are in the same plane
-				 */
 
 /* This is client data passed down through the various DRC checking
  * routines, and contains information about the area and rule being
@@ -131,6 +101,7 @@ struct drcClientData
  * some sort.  These are linked together for processing by the
  * continuous checker.
  */
+#define DRCYANK	"__DRCYANK__"	/* predefined DRC yank buffer */
 
 typedef struct drcpendingcookie
 {
@@ -138,10 +109,6 @@ typedef struct drcpendingcookie
     struct drcpendingcookie *dpc_next;
 } DRCPendingCookie;
 
-extern DRCPendingCookie * DRCPendingRoot;
-
-#define DRCYANK	"__DRCYANK__"	/* predefined DRC yank buffer */
-
 /* Structure used to pass back lists of cell definitions and error tile counts */
 
 typedef struct drccountlist
@@ -151,20 +118,51 @@ typedef struct drccountlist
     struct drccountlist	*dcl_next;
 } DRCCountList;
 
+/* Structure used to keep information about the current DRC style */
+
+typedef struct drckeep
+{
+    struct drckeep	*ds_next;
+    char		*ds_name;
+} DRCKeep;
+
+/*
+ * DRC "why" strings are potentially referred to hundreds of times by
+ * DRC cookies in the rule table.  Rather than creating hundreds of
+ * copies of each string, we create just one copy and let all the cookies
+ * point to that one copy.
+ *
+ * Since we can't free these shared "why" strings when we delete a cookie,
+ * we keep a list of these strings and free them all when convenient.
+ */
+    
+typedef struct drcwhylist
+{
+    char                * dwl_string;
+    struct drcwhylist   * dwl_next;
+} drcWhyList;      
+ 
+/*
+ * Structure defining a DRC style
+ */
+
+typedef struct drcstyle
+{
+    char		ds_status;	/* Status:  Loaded, not loaded, or pending */
+    char		*ds_name;	/* Name of this DRC style */
+    DRCCookie        	*DRCRulesTbl[TT_MAXTYPES][TT_MAXTYPES];
+    TileTypeBitMask     DRCExactOverlapTypes;
+    int			DRCScaleFactor;	/* Divide dist by this to get magic units */
+    int			DRCTechHalo;	/* largest action distance of design rules */
+    int			DRCStepSize;	/* chunk size for decomposing large areas */
+    drcWhyList		*DRCWhyList;
+    PaintResultType	DRCPaintTable[NP][NT][NT];
+} DRCStyle;
+
 /* Things shared between DRC functions, but not used by the
  * outside world:
  */
 
-extern int  dbDRCDebug;
-extern int  TechHalo;	      	/* largest action distance of design rules */
-extern int  MaxHalo;
-extern int  DRCStepSize;	/* chunk size for decomposing large areas */
-extern PaintResultType DRCPaintTable[NP][NT][NT];
-#ifdef NONMANHATTAN
-extern PaintResultType DRCEraseTable[NP][NT][NT];
-#endif
-extern TileTypeBitMask DRCExactOverlapTypes;
-
 extern int  DRCstatEdges;	/* counters for statistics gathering */
 extern int  DRCstatSlow;
 extern int  DRCstatRules;
@@ -181,6 +179,27 @@ extern int  DRCstatHRulesHisto[DRC_MAXRULESHISTO];
 extern int  DRCstatVRulesHisto[DRC_MAXRULESHISTO];
 #endif	/* DRCRULESHISTO */
 
+extern int DRCTechHalo;		/* Current halo being used */
+extern int DRCStepSize;		/* Current step size being used */
+extern DRCPendingCookie * DRCPendingRoot;
+
+extern bool DRCBackGround;	/* global flag to enable/disable
+				 * continuous DRC
+			     	 */
+extern bool DRCEuclidean;	/* global flag to enable/disable
+				 * Euclidean distance measure
+				 */
+extern int  dbDRCDebug;
+
+extern DRCKeep  *DRCStyleList;	/* List of available DRC styles */
+extern DRCStyle *DRCCurStyle;	/* Current DRC style in effect */
+extern CellDef  *DRCdef;	/* Current cell being checked for DRC */
+extern CellUse  *DRCuse, *DRCDummyUse;
+
+/* 
+ * Internal procedures
+ */
+
 extern void drcPaintError();
 extern void drcPrintError();
 extern int drcIncludeArea();
@@ -188,23 +207,22 @@ extern int drcExactOverlapTile();
 extern Rect *drcCanonicalMaxwidth();
 extern void drcInitRulesTbl();
 
-extern CellUse *DRCuse, *DRCDummyUse;
-extern CellDef *DRCdef;
-
 /*
- * Exported procedures and variables.
+ * Exported procedures
  */
 
 extern int DRCGetDefaultLayerWidth();
 extern int DRCGetDefaultLayerSpacing();
 
 extern void DRCTechInit();
+extern bool DRCTechLine();
 extern bool DRCTechAddRule();
+extern void DRCTechStyleInit();
 extern void DRCTechFinal();
 extern void DRCTechRuleStats();
+extern void DRCTechScale();
 
 extern void DRCInit();
-extern void DRCPreInit();
 extern void DRCContinuous();
 extern void DRCCheckThis();
 extern void DRCRemovePending();
@@ -215,17 +233,12 @@ extern void DRCCheck();
 extern DRCCountList *DRCCount();
 extern int DRCFind();
 extern void DRCCatchUp();
-
-extern bool DRCBackGround;	/* global flag to enable/disable
-				 * continuous DRC
-			     	 */
-extern bool DRCEuclidean;	/* global flag to enable/disable
-				 * Euclidean distance measure
-				 */
-extern DRCPendingCookie *DRCPendingRoot;
-extern CellDef *DRCdef;
 extern bool DRCFindInteractions();
 
+extern void DRCPrintStyle();
+extern void DRCSetStyle();
+extern void DRCLoadStyle();
+
 /* The following macro can be used by the outside world to see if
  * the background checker needs to be called.
  */
