@@ -185,7 +185,8 @@ Exttosim_Init(interp)
 {
     /* Sanity checks! */
     if (interp == NULL) return TCL_ERROR;
-    if (Tcl_PkgRequire(interp, "Tclmagic", "7.3", 0) == NULL) return TCL_ERROR;
+    if (Tcl_PkgRequire(interp, "Tclmagic", MAGIC_VERSION, 0) == NULL)
+	return TCL_ERROR;
     if (Tcl_InitStubs(interp, "8.1", 0) == NULL) return TCL_ERROR;
 
     TxPrintf("Auto-loading EXTTOSIM module\n");
@@ -201,7 +202,7 @@ Exttosim_Init(interp)
     if (WindReplaceCommand(DBWclientID, "ext2sim", CmdExtToSim) < 0)
 	return TCL_ERROR;
 
-    Tcl_PkgProvide(interp, "Exttosim", "7.3");
+    Tcl_PkgProvide(interp, "Exttosim", MAGIC_VERSION);
     return TCL_OK;
 }
 
