@@ -16,13 +16,13 @@
  *     * of the United States of America may require an export license.    * 
  *     *********************************************************************
  *
- * rcsid $Header: /ufs/repository/magic/extflat/EFint.h,v 1.2 2001/01/12 22:12:35 jsolomon Exp $
+ * rcsid $Header: /usr/cvsroot/magic/extflat/EFint.h,v 1.1.1.1 2005/05/09 23:29:23 tim Exp $
  */
 
-#ifndef	_MAGIC
-int err0 = Need_to_include_misc/magic_header;
-#endif	/* _MAGIC */
+#ifndef _EFINT_H
+#define _EFINT_H
 
+#include "utils/magic.h"
 
 /*
  * Add in the next character value to a hash sum.
@@ -182,14 +182,14 @@ typedef struct def
  * structure describes the indices and the separation between elements
  * (for computing transforms).
  */
-#ifndef _DATABASE
+#ifndef _DATABASE_H
 typedef struct
 {
     int		 ar_xlo, ar_xhi;
     int		 ar_ylo, ar_yhi;
     int		 ar_xsep, ar_ysep;
 } ArrayInfo;
-#endif
+#endif /* _DATABASE_H */
 
 typedef struct use
 {
@@ -270,12 +270,14 @@ extern HashTable efDistHashTable;
 extern HashTable efWatchTable;
 extern bool efWatchNodes;
 extern EFNode efNodeList;
+extern Def *efFlatRootDef;
 
 /* --------------------- Internally used procedures ------------------- */
 
     /* Def table management */
 extern Def *efDefLook();
 extern Def *efDefNew();
+extern Def *EFRootDef();
 
     /* HierName manipulation */
 extern HierName *efHNFromUse();
@@ -286,17 +288,17 @@ extern int efHNCompare();
 extern int efHNHash();
 
     /* Functions for hashing of Distances */
-extern int efHNDistCompare();
+extern bool efHNDistCompare();
 extern char *efHNDistCopy();
 extern int efHNDistHash();
 extern void efHNDistKill();
 
     /* Functions for hashing of use id HierNames */
-extern int efHNUseCompare();
+extern bool efHNUseCompare();
 extern int efHNUseHash();
 
 extern EFCapValue CapHashGetValue();
-extern int CapHashSetValue();
+extern void CapHashSetValue();
 
    /* efBuild procedures */
 /* Warning: The capacitance argument to these should be always double
@@ -308,3 +310,5 @@ extern void efBuildNode();
 extern void efBuildConnect();
 extern void efBuildResistor();
 extern void efBuildCap();
+
+#endif /* _EFINT_H */
