@@ -17,7 +17,7 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Header: /ufs/repository/magic/extflat/EFname.c,v 1.4 2001/07/06 17:58:39 rajit Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/extflat/EFname.c,v 1.1.1.1 2005/05/09 23:29:23 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -25,7 +25,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extflat/EFname.c,v 1.4 200
 #include <math.h>
 
 #include "tcltk/tclmagic.h"
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "utils/hash.h"
@@ -69,7 +69,9 @@ extern void efHNRecord();
  * i.e, it ends in a '!'.
  * 
  * The Tcl version of magic further refines this to include names
- * which are defined in the global Tcl variable space.
+ * which are defined in the global Tcl variable space.  (7.3.94):
+ * also check if the array variable "globals" contains the name as
+ * a key entry.
  *
  * Results:
  *	TRUE if the name is a global.
@@ -86,6 +88,10 @@ EFHNIsGlob(hierName)
 {
 #ifdef MAGIC_WRAPPER
     char *retstr;
+    retstr = (char *)Tcl_GetVar2(magicinterp, "globals", hierName->hn_name,
+		TCL_GLOBAL_ONLY);
+    if (retstr != NULL) return TRUE;
+
     retstr = (char *)Tcl_GetVar(magicinterp, hierName->hn_name, TCL_GLOBAL_ONLY);
     if (retstr != NULL) return TRUE;
 #endif
@@ -682,12 +688,13 @@ efHNFromUse(hc, prefix)
  * ----------------------------------------------------------------------------
  */
 
-int
+bool
 efHNUseCompare(hierName1, hierName2)
     HierName *hierName1, *hierName2;
 {
-    return (hierName1->hn_parent != hierName2->hn_parent
-	    || strcmp(hierName1->hn_name, hierName2->hn_name));
+    return ((bool)(hierName1->hn_parent != hierName2->hn_parent
+	           || strcmp(hierName1->hn_name, hierName2->hn_name)
+		  ));
 }
 
 int
@@ -833,12 +840,13 @@ efHNHash(hierName)
  * ----------------------------------------------------------------------------
  */
 
-int
+bool
 efHNDistCompare(dist1, dist2)
     Distance *dist1, *dist2;
 {
-    return efHNCompare(dist1->dist_1, dist2->dist_1)
-	|| efHNCompare(dist1->dist_2, dist2->dist_2);
+    return ((bool)(efHNCompare(dist1->dist_1, dist2->dist_1)
+	           || efHNCompare(dist1->dist_2, dist2->dist_2)
+		  ));
 }
 
 char *
