@@ -18,7 +18,7 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Header: /ufs/repository/magic/extflat/EFvisit.c,v 1.2 2001/01/12 22:12:36 jsolomon Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/extflat/EFvisit.c,v 1.1.1.1 2005/05/09 23:29:23 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -26,7 +26,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extflat/EFvisit.c,v 1.2 20
 #include <string.h>
 #include <math.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "utils/hash.h"
@@ -196,7 +196,10 @@ EFGetLengthAndWidth(dev, lptr, wptr)
 
 	    if (dev->dev_nterm == 2)
 	    {
-		l = (perim - (int) sqrt((float)(perim * perim - 16 * area))) / 4;
+		/* Convert area to type double to avoid overflow in	*/
+		/* extreme cases.					*/
+		l = perim - (int)sqrt((double)(perim * perim) - 16 * (double)area);
+		l >>= 2;
 		w = area / l;
 	    }
 	    else
