@@ -18,17 +18,16 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Header: /ufs/repository/magic/extract/ExtCell.c,v 1.2 2001/01/12 22:12:37 jsolomon Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/extract/ExtCell.c,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
 #include <math.h>
-#ifdef SYSV
 #include <string.h>
-#endif
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
@@ -37,33 +36,24 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extract/ExtCell.c,v 1.2 20
 #include "debug/debug.h"
 #include "extract/extract.h"
 #include "extract/extractInt.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "utils/stack.h"
 #include "utils/utils.h"
 #include "windows/windows.h"
-#include "main/main.h"
-#include "undo/undo.h"
+#include "utils/main.h"
+#include "utils/undo.h"
 
 /* --------------------------- Global data ---------------------------- */
 
-/* Used to identify the extractor version that produced a .ext file */
-
-/* NOTE:  I don't know if this was originally intended to track the	*/
-/* magic version number, but I am making it so.  Tim, 2/20/03		*/
-/* (this number is picked up from extract/Makefile and ultimately	*/
-/* derives from the VERSION string in scripts/config)			*/
-
-char *ExtVersionString = MAGIC_VERSION;
-
-    /*
-     * Value normally present in ti_client to indicate tiles that have not
-     * been marked with their associated region.
-     */
+/*
+ * Value normally present in ti_client to indicate tiles that have not
+ * been marked with their associated region.
+ */
 ClientData extUnInit = (ClientData) MINFINITY;
 
 /* ------------------------ Data local to this file ------------------- */
 
-    /* Forward declarations */
+/* Forward declarations */
 int extOutputUsesFunc();
 FILE *extFileOpen();
 
@@ -288,16 +278,16 @@ extHeader(def, f)
     int n;
 
     /* Output a timestamp (should be first) */
-    (void) fprintf(f, "timestamp %d\n", def->cd_timestamp);
+    fprintf(f, "timestamp %d\n", def->cd_timestamp);
 
     /* Output our version number */
-    (void) fprintf(f, "version %s\n", ExtVersionString);
+    fprintf(f, "version %s\n", MagicVersion);
 
     /* Output the technology */
-    (void) fprintf(f, "tech %s\n", DBTechName);
+    fprintf(f, "tech %s\n", DBTechName);
 
     /* Output the extract style name */
-    (void) fprintf(f, "style %s\n", ExtCurStyle->exts_name);
+    fprintf(f, "style %s\n", ExtCurStyle->exts_name);
 
     /*
      * Output scaling factors: R C D
@@ -306,16 +296,16 @@ extHeader(def, f)
      *		D = amount to multiply all linear distances by (areas
      *		    should be multiplied by D**2).
      */
-    (void) fprintf(f, "scale %d %d %d\n",
+    fprintf(f, "scale %d %d %d\n",
 		ExtCurStyle->exts_resistScale,
 		ExtCurStyle->exts_capScale,
 		ExtCurStyle->exts_unitsPerLambda);
 
     /* Output the sheet resistivity classes */
-    (void) fprintf(f, "resistclasses");
+    fprintf(f, "resistclasses");
     for (n = 0; n < ExtCurStyle->exts_numResistClasses; n++)
-	(void) fprintf(f, " %d", ExtCurStyle->exts_resistByResistClass[n]);
-    (void) fprintf(f, "\n");
+	fprintf(f, " %d", ExtCurStyle->exts_resistByResistClass[n]);
+    fprintf(f, "\n");
 
     /* Output all calls on subcells */
     (void) DBCellEnum(def, extOutputUsesFunc, (ClientData) f);
@@ -361,17 +351,17 @@ extOutputUsesFunc(cu, outf)
 {
     Transform *t = &cu->cu_transform;
 
-    (void) fprintf(outf, "use %s %s", cu->cu_def->cd_name, cu->cu_id);
+    fprintf(outf, "use %s %s", cu->cu_def->cd_name, cu->cu_id);
     if (cu->cu_xlo != cu->cu_xhi || cu->cu_ylo != cu->cu_yhi)
     {
-	(void) fprintf(outf, "[%d:%d:%d]",
+	fprintf(outf, "[%d:%d:%d]",
 			cu->cu_xlo, cu->cu_xhi, cu->cu_xsep);
-	(void) fprintf(outf, "[%d:%d:%d]",
+	fprintf(outf, "[%d:%d:%d]",
 			cu->cu_ylo, cu->cu_yhi, cu->cu_ysep);
     }
 
     /* Output transform to parent */
-    (void) fprintf(outf, " %d %d %d %d %d %d\n",
+    fprintf(outf, " %d %d %d %d %d %d\n",
 			t->t_a, t->t_b, t->t_c, t->t_d, t->t_e, t->t_f);
 
     return (0);
