@@ -16,9 +16,7 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/lef/
 
 #include <stdio.h>
 #include <stdlib.h>
-#ifdef SYSV
 #include <string.h>
-#endif
 #include <errno.h>
 
 #include "tcltk/tclmagic.h"
@@ -58,6 +56,7 @@ typedef struct {
    float scale;
    int total;
    int plane;
+   TileTypeBitMask *mask;
    LefMapping *MagicToLefTbl;
 } CViaData;
 
@@ -692,6 +691,7 @@ defnodeVisit(node, res, cap, defdata)
     /* in the subcircuit itself, so we need to search for any type */
     /* that might validly connect to it, not just the type itself. */
     /* TTMaskSetOnlyType(&tmask, magictype); */
+    TTMaskZero(&tmask);
     TTMaskSetMask(&tmask, &DBConnectTbl[magictype]);
 
     DBSrConnect(def, &node->efnode_loc, &tmask, DBConnectTbl,
@@ -792,11 +792,16 @@ defNetGeometryFunc(tile, plane, defdata)
     char *lefName, viaName[20];
     LefMapping *MagicToLefTable = defdata->MagicToLefTbl;
 
-    /* If this is a contact type, we need to make sure we only process	*/
-    /* it on its home plane.						*/
+    TiToRect(tile, &r);
+
+    /* Treat contacts here exactly the same way as defCountVias	*/
 
     if (DBIsContact(ttype))
     {
+	Rect r2;
+	Tile *tp;
+
+	rMask = NULL;
 	if (ttype >= DBNumUserLayers)
 	{
 	    /* Stacked contact types need to be broken into their	*/
@@ -805,28 +810,80 @@ defNetGeometryFunc(tile, plane, defdata)
 
 	    rMask = DBResidueMask(ttype);
 	    for (rtype = TT_TECHDEPBASE; rtype < DBNumUserLayers; rtype++)
-	    {
 		if (TTMaskHasType(rMask, rtype))
-		{
 		    if (DBPlane(rtype) == plane)
 		    {
 			ttype = rtype;
 			break;
 		    }
-		}
-	    }
 	    if (rtype == DBNumUserLayers)
 		return 0;
+
 	}
 	else
-	{
 	    if (DBPlane(ttype) != plane)
 		return 0;
+
+	/* Boundary search on stacked contact types to include any	*/
+	/* tile areas belonging to ttype.				*/
+
+	for (tp = RT(tile); RIGHT(tp) > LEFT(tile); tp = BL(tp)) /* Top */
+	{
+	    r2type = TiGetBottomType(tp);
+	    if (r2type == ttype)
+	    {
+		if (!rMask) return 0;
+		TiToRect(tp, &r2);
+		GeoInclude(&r2, &r);
+	    }
+	    else if (r2type >= DBNumUserLayers)
+		if (TTMaskHasType(DBResidueMask(r2type), ttype))
+		    return 0;
+	}
+
+	for (tp = BL(tile); BOTTOM(tp) < TOP(tile); tp = RT(tp)) /* Left */
+	{
+	    r2type = TiGetRightType(tp);
+	    if (r2type == ttype)
+	    {
+		if (!rMask) return 0;
+		TiToRect(tp, &r2);
+		GeoInclude(&r2, &r);
+	    }
+	    else if (r2type >= DBNumUserLayers)
+		if (TTMaskHasType(DBResidueMask(r2type), ttype))
+		    return 0;
+	}
+
+	for (tp = LB(tile); LEFT(tp) < RIGHT(tile); tp = TR(tp)) /* Bottom */
+	{
+	    r2type = TiGetTopType(tp);
+	    if (r2type == ttype)
+	    {
+		if (!rMask) return 0;
+		TiToRect(tp, &r2);
+		GeoInclude(&r2, &r);
+	    }
+	    else if (r2type >= DBNumUserLayers)
+		if (TTMaskHasType(DBResidueMask(r2type), ttype))
+		    return 0;
+	}
+
+	for (tp = TR(tile); TOP(tp) > BOTTOM(tile); tp = LB(tp)) /* Right */
+	{
+	    r2type = TiGetLeftType(tp);
+	    if (r2type == ttype)
+	    {
+		if (!rMask) return 0;
+		TiToRect(tp, &r2);
+		GeoInclude(&r2, &r);
+	    }
+	    else if (r2type >= DBNumUserLayers)
+		if (TTMaskHasType(DBResidueMask(r2type), ttype))
+		    return 0;
 	}
     }
 
-    TiToRect(tile, &r);
-
     /* Layer names are taken from the LEF database. */
 
     lefName = MagicToLefTable[ttype].lefName;
@@ -956,19 +1013,36 @@ defNetGeometryFunc(tile, plane, defdata)
 	/* direction of the route.					*/ 
 	/* NOTE:  We should compute this FIRST and use it to determine	*/
 	/* the current route direction!					*/
+	/* Another hack---for special nets, don't continue routes that	*/
+	/* have different widths, even if they're connected in the	*/
+	/* direction of travel.  A separate record will be written for	*/
+	/* the segment of different width.				*/
 
-	if (defdata->orient == GEO_EAST)
+	if (GEO_TOUCH(&r, &r2))
 	{
-	    if ((r.r_xbot == r2.r_xtop) || (r.r_xtop == r2.r_xbot))
+	    if (defdata->orient == GEO_EAST)
+	    {
+		if ((r.r_xbot == r2.r_xtop) || (r.r_xtop == r2.r_xbot))
+		{
+		    sameroute = TRUE;
+		    if ((defdata->specialmode != DO_REGULAR) &&
+				(r.r_ytop != r2.r_ytop || r.r_ybot != r2.r_ybot))
+			sameroute = FALSE;
+		}
+	    }
+	    else if (defdata->orient == GEO_NORTH)
+	    {
+		if ((r.r_ybot == r2.r_ytop) || (r.r_ytop == r2.r_ybot))
+		{
+		    sameroute = TRUE;
+		    if ((defdata->specialmode != DO_REGULAR) &&
+				(r.r_xtop != r2.r_xtop || r.r_xbot != r2.r_xbot))
+			sameroute = FALSE;
+		}
+	    }
+	    else
 		sameroute = TRUE;
 	}
-	else if (defdata->orient == GEO_NORTH)
-	{
-	    if ((r.r_ybot == r2.r_ytop) || (r.r_ytop == r2.r_ybot))
-		sameroute = TRUE;
-	}
-	else
-	    if (GEO_TOUCH(&r, &r2)) sameroute = TRUE;
 
 	/* We should NOT continue a route from a via for a special net,	*/
 	/* because the spec for this situation is too vaguely defined.	*/
@@ -1046,7 +1120,14 @@ defNetGeometryFunc(tile, plane, defdata)
 
 	    if (orient == GEO_CENTER)
 	    {
-		char *rName = defGetType(rtype, NULL);
+		char *rName;
+
+		/* Type can be zero (space) if the first tile	*/
+		/* encountered is a via.  If so, use the 1st	*/
+		/* residue of the contact as the route layer	*/
+		/* type.					*/
+
+		rName = defGetType((rtype == TT_SPACE) ? r2type : rtype, NULL);
 
 		/* The first layer in a record may not be a via name */
 
@@ -1211,8 +1292,8 @@ defCountVias(rootDef, MagicToLefTable, oscale)
     LefMapping *MagicToLefTable;
     float oscale;
 {
-    TileTypeBitMask contactMask;
-    TileType ttype;
+    TileTypeBitMask contactMask, *rmask;
+    TileType ttype, stype;
     int pNum;
     CViaData cviadata;
     int defCountViaFunc();
@@ -1221,14 +1302,33 @@ defCountVias(rootDef, MagicToLefTable, oscale)
     cviadata.total = 0;
     cviadata.MagicToLefTbl = MagicToLefTable;
 
-    TTMaskZero(&contactMask);
-    for (ttype = TT_TECHDEPBASE; ttype < DBNumTypes; ttype++)
-	if (DBIsContact(ttype))
-	    TTMaskSetType(&contactMask, ttype);
- 
     for (pNum = PL_SELECTBASE; pNum < DBNumPlanes; pNum++)
     {
 	cviadata.plane = pNum;
+
+        /* Only search for contacts that are on their *home* plane */
+
+	TTMaskZero(&contactMask);
+	for (ttype = TT_TECHDEPBASE; ttype < DBNumUserLayers; ttype++)
+	    if (DBIsContact(ttype) && TTMaskHasType(&DBPlaneTypes[pNum], ttype))
+		TTMaskSetType(&contactMask, ttype);
+
+	/* Also search all stacked types whose residue contact types	*/
+	/* are in the mask just generated.				*/
+
+	for (ttype = DBNumUserLayers; ttype < DBNumTypes; ttype++)
+	{
+	    if (!DBIsContact(ttype)) continue;
+	    rmask = DBResidueMask(ttype);
+	    for (stype = TT_TECHDEPBASE; stype < DBNumUserLayers; stype++)
+		if (TTMaskHasType(rmask, stype))
+		{
+		    TTMaskSetType(&contactMask, ttype);
+		    break;
+		}
+	}
+	cviadata.mask = &contactMask;
+
 	DBSrPaintArea((Tile *)NULL, rootDef->cd_planes[pNum],
 			&TiPlaneRect, &contactMask,
 			defCountViaFunc, (ClientData)&cviadata);
@@ -1243,9 +1343,11 @@ defCountViaFunc(tile, cviadata)
     Tile *tile;
     CViaData *cviadata;
 {
-    TileType ttype = TiGetType(tile);
+    TileType ttype = TiGetType(tile), ctype, rtype;
+    TileTypeBitMask *rmask;
+    Tile *tp;
     char *lname, vname[100], *vp;
-    Rect r;
+    Rect r, r2;
     int w, h, offx, offy;
     float oscale = cviadata->scale;
     lefLayer *lefl;
@@ -1256,24 +1358,93 @@ defCountViaFunc(tile, cviadata)
     /* case we would need to initialize the hash table.		  */
     if (LefInfo.ht_table == (HashEntry **) NULL) LefTechInit();
 
-    /* Only deal with vias on their home plane */
-
-    if (ttype >= DBNumUserLayers) {
-        TileTypeBitMask *rMask = DBResidueMask(ttype);
-	for (ttype = TT_TECHDEPBASE; ttype < DBNumUserLayers; ttype++)
-	    if (TTMaskHasType(rMask, ttype) &&
-			(DBPlane(ttype) == cviadata->plane))
+    /* Find the canonical type */
+    if (ttype >= DBNumUserLayers)
+    {
+	rmask = DBResidueMask(ttype);
+	for (ctype = TT_TECHDEPBASE; ctype < DBNumUserLayers; ctype++)
+	    if (TTMaskHasType(rmask, ctype))
 		break;
-	
-	if (ttype == DBNumUserLayers) return 0;
+	if (ctype == DBNumUserLayers)
+	    return 1;			/* Error condition */
+    }
+    else
+    {
+	rmask = NULL;
+	ctype = ttype;
     }
-    else if (DBPlane(ttype) != cviadata->plane) return 0;
 
     /* Generate a via name from the layer name and tile size */
 
-    lname = MagicToLefTable[ttype].lefName;
+    lname = MagicToLefTable[ctype].lefName;
     TiToRect(tile, &r);
 
+    /* Boundary search.  WARNING:  This code is quite naive.  The	*/
+    /* assumption is that all contacts are rectangular, and therefore	*/
+    /* any contact area consisting of multiple tiles must be an amalgam	*/
+    /* of regular and/or stacked types.  This whole thing should be	*/
+    /* replaced by calls to generate layers via the CIF/Calma code.	*/
+
+    /* Top */
+    for (tp = RT(tile); RIGHT(tp) > LEFT(tile); tp = BL(tp))
+    {
+	rtype = TiGetBottomType(tp);
+	if (rtype == ctype)
+	{
+	    if (!rmask) return 0; /* ignore tile but continue search */
+	    TiToRect(tp, &r2);
+	    GeoInclude(&r2, &r);
+	}
+	else if (rtype >= DBNumUserLayers)
+	    if (TTMaskHasType(DBResidueMask(rtype), ctype))
+		return 0;
+    }
+
+    /* Left */
+    for (tp = BL(tile); BOTTOM(tp) < TOP(tile); tp = RT(tp))
+    {
+	rtype = TiGetRightType(tp);
+	if (rtype == ctype)
+	{
+	    if (!rmask) return 0; /* ignore tile but continue search */
+	    TiToRect(tp, &r2);
+	    GeoInclude(&r2, &r);
+	}
+	else if (rtype >= DBNumUserLayers)
+	    if (TTMaskHasType(DBResidueMask(rtype), ctype))
+		return 0;
+    }
+
+    /* Bottom */
+    for (tp = LB(tile); LEFT(tp) < RIGHT(tile); tp = TR(tp))
+    {
+	rtype = TiGetTopType(tp);
+	if (rtype == ctype)
+	{
+	    if (!rmask) return 0; /* ignore tile but continue search */
+	    TiToRect(tp, &r2);
+	    GeoInclude(&r2, &r);
+	}
+	else if (rtype >= DBNumUserLayers)
+	    if (TTMaskHasType(DBResidueMask(rtype), ctype))
+		return 0;
+    }
+
+    /* Right */
+    for (tp = TR(tile); TOP(tp) > BOTTOM(tile); tp = LB(tp))
+    {
+	rtype = TiGetLeftType(tp);
+	if (rtype == ctype)
+	{
+	    if (!rmask) return 0; /* ignore tile but continue search */
+	    TiToRect(tp, &r2);
+	    GeoInclude(&r2, &r);
+	}
+	else if (rtype >= DBNumUserLayers)
+	    if (TTMaskHasType(DBResidueMask(rtype), ctype))
+		return 0;
+    }
+
     /* All values for the via rect are in 1/2 lambda to account */
     /* for a centerpoint not on the internal grid.		*/
 
