@@ -18,13 +18,13 @@
  */
 
 #ifndef lint
-static char rcsid[]="$Header: /ufs/repository/magic/plot/plotVers.c,v 1.2 2001/01/12 22:13:10 jsolomon Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/plot/plotVers.c,v 1.1.1.1 2005/05/09 23:29:23 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
 #include <string.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "tiles/tile.h"
@@ -36,10 +36,12 @@ static char rcsid[]="$Header: /ufs/repository/magic/plot/plotVers.c,v 1.2 2001/0
 #include "commands/commands.h"
 #include "textio/textio.h"
 #include "utils/utils.h"
-#include "tech/tech.h"
-#include "signals/signals.h"
+#include "utils/tech.h"
+#include "utils/signals.h"
 #include "dbwind/dbwind.h"
 
+#ifdef VERSATEC
+
 /* Library imports: */
 
 extern int rasFileByteCount; 
@@ -185,6 +187,8 @@ static int crossSize;		/* Length of each arm of the crosses used
 static Font *labelFont;		/* Font to use when rendering labels. */
 static Font *cellNameFont;	/* Font to use when rendering cell names. */
 static Font *cellIdFont;	/* Font to use when rendering cell ids. */
+
+#endif /* VERSATEC */
 
 /*
  * ----------------------------------------------------------------------------
@@ -201,6 +205,8 @@ static Font *cellIdFont;	/* Font to use when rendering cell ids. */
  * ----------------------------------------------------------------------------
  */
 
+#ifdef VERSATEC
+
 void
 PlotVersTechInit()
 {
@@ -225,6 +231,15 @@ PlotVersTechInit()
     if (PlotVersLabelFont == NULL)
 	StrDup(&PlotVersLabelFont, defaultLabelFont);
 }
+
+#else
+
+void
+PlotVersTechInit()
+{}
+
+#endif /* VERSATEC */
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -241,6 +256,8 @@ PlotVersTechInit()
  * ----------------------------------------------------------------------------
  */
 
+#ifdef VERSATEC
+
 void
 PlotColorVersTechInit()
 {
@@ -265,6 +282,15 @@ PlotColorVersTechInit()
     if (PlotVersLabelFont == NULL)
 	StrDup(&PlotVersLabelFont, defaultLabelFont);
 }
+
+#else
+
+void
+PlotColorVersTechInit()
+{}
+
+#endif /* VERSATEC */
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -283,7 +309,8 @@ PlotColorVersTechInit()
  * ----------------------------------------------------------------------------
  */
 
-	/* ARGSUSED */
+#ifdef VERSATEC
+
 bool
 PlotVersTechLine(sectionName, argc, argv)
     char *sectionName;		/* Name of this section (unused). */
@@ -338,9 +365,9 @@ PlotVersTechLine(sectionName, argc, argv)
 	{
 	    (void) sscanf(argv[i+1], "%x", &value);
 	    new->vs_stipple[i] = (value<<16) | (value & 0xffff);
-#ifndef IS_BIG_ENDIAN
+#ifndef WORDS_BIGENDIAN
 	    new->vs_stipple[i] = PlotSwapBytes(new->vs_stipple[i]);
-#endif  /* IS_BIG_ENDIAN */
+#endif  /* WORDS_BIGENDIAN */
 	}
     }
 
@@ -349,7 +376,20 @@ PlotVersTechLine(sectionName, argc, argv)
 
     return TRUE;
 }
-
+
+#else
+
+bool
+PlotVersTechLine(sectionName, argc, argv)
+    char *sectionName;		/* Name of this section (unused). */
+    int argc;			/* Number of arguments on line. */
+    char *argv[];		/* Pointers to fields of line. */
+{
+    return TRUE;
+}
+
+#endif /* VERSATEC */
+
 /*
  * ----------------------------------------------------------------------------
  *	PlotColorVersTechLine --
@@ -367,7 +407,8 @@ PlotVersTechLine(sectionName, argc, argv)
  * ----------------------------------------------------------------------------
  */
 
-	/* ARGSUSED */
+#ifdef VERSATEC
+
 bool
 PlotColorVersTechLine(sectionName, argc, argv)
     char *sectionName;		/* Name of this section (unused). */
@@ -446,7 +487,22 @@ PlotColorVersTechLine(sectionName, argc, argv)
 
     return TRUE;
 }
-
+
+#else
+
+bool
+PlotColorVersTechLine(sectionName, argc, argv)
+    char *sectionName;		/* Name of this section (unused). */
+    int argc;			/* Number of arguments on line. */
+    char *argv[];		/* Pointers to fields of line. */
+{
+    return TRUE;
+}
+
+#endif /* VERSATEC */
+
+#ifdef VERSATEC
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -1263,3 +1319,4 @@ PlotVersatec(scx, layers, xMask, width)
     unlink(fileName);
 }
 
+#endif /* VERSATEC */
