@@ -354,10 +354,10 @@ PlowStraighten(def, area, direction)
     plowDummyUse->cu_def = def;
     UndoDisable();
     DBCellClearDef(plowYankDef);
-    plowYankedArea.r_xbot = yankArea.r_xbot - TechHalo;
-    plowYankedArea.r_ybot = yankArea.r_ybot - TechHalo;
-    plowYankedArea.r_xtop = yankArea.r_xtop + TechHalo;
-    plowYankedArea.r_ytop = yankArea.r_ytop + TechHalo;
+    plowYankedArea.r_xbot = yankArea.r_xbot - DRCTechHalo;
+    plowYankedArea.r_ybot = yankArea.r_ybot - DRCTechHalo;
+    plowYankedArea.r_xtop = yankArea.r_xtop + DRCTechHalo;
+    plowYankedArea.r_ytop = yankArea.r_ytop + DRCTechHalo;
     scx.scx_use = plowDummyUse;
     scx.scx_trans = plowYankTrans;
     GeoTransRect(&plowInverseTrans, &plowYankedArea, &scx.scx_area);
@@ -2024,7 +2024,7 @@ plowMergeBottom(tp, plane)
  * from the original cell.  If this halo extends outside plowYankedArea
  * or touches it, we yank more.  The size of the halo should be such
  * that most of the plowing rules are guaranteed not to visit any area
- * outside of it.  Currently, TechHalo is sufficient; only the rules
+ * outside of it.  Currently, DRCTechHalo is sufficient; only the rules
  * moving whole tiles need anything bigger than this, and they are
  * responsible for doing their own yanking if they need it.
  *
@@ -2193,7 +2193,7 @@ PlowInit()
     plowDebugInit();
 
     /* Initialize the yank halo */
-    plowYankHalo = TechHalo;
+    plowYankHalo = DRCTechHalo;
 }
 
 void
