@@ -356,7 +356,7 @@ plowDragEdgeProc(lhsEdge, movingEdge)
 	return (0);
 
     /* Don't bother doing any more work if it's too far to the left */
-    if (lhsEdge->e_x + TechHalo < movingEdge->e_x)
+    if (lhsEdge->e_x + DRCTechHalo < movingEdge->e_x)
 	return (0);
 
     /*
@@ -749,7 +749,7 @@ plowIllegalTopProc(outline, ar)
 	return (1);
 
     /* Ignore if this is a legal edge */
-    for (dp = DRCRulesTbl[movingEdge->e_ltype][badType];
+    for (dp = DRCCurStyle->DRCRulesTbl[movingEdge->e_ltype][badType];
 	    dp; dp = dp->drcc_next)
     {
 	if (!TTMaskHasType(&dp->drcc_mask, badType))
@@ -795,7 +795,7 @@ plowIllegalBotProc(outline, ar)
 	return (1);
 
     /* Ignore if this is a legal edge */
-    for (dp = DRCRulesTbl[movingEdge->e_ltype][badType];
+    for (dp = DRCCurStyle->DRCRulesTbl[movingEdge->e_ltype][badType];
 	    dp; dp = dp->drcc_next)
     {
 	if (!TTMaskHasType(&dp->drcc_mask, badType))
@@ -855,9 +855,9 @@ prFindCells(edge)
     Rect searchArea;
 
     searchArea.r_xbot = edge->e_x - 1;
-    searchArea.r_ybot = edge->e_ybot - TechHalo;
-    searchArea.r_ytop = edge->e_ytop + TechHalo;
-    searchArea.r_xtop = edge->e_newx + TechHalo;
+    searchArea.r_ybot = edge->e_ybot - DRCTechHalo;
+    searchArea.r_ytop = edge->e_ytop + DRCTechHalo;
+    searchArea.r_xtop = edge->e_newx + DRCTechHalo;
     ar.ar_moving = edge;
 
     /*
@@ -881,7 +881,7 @@ prFindCells(edge)
  * prCell --
  *
  * The Edge 'edge' corresponds to a cell that is moving.  Search the
- * area of the cell plus a TechHalo around it for geometry to move,
+ * area of the cell plus a DRCTechHalo around it for geometry to move,
  * and queue each edge found.  Also, search to its right for other
  * cells to move and move them.
  *
@@ -907,15 +907,15 @@ prCell(edge)
 
     /* Search area for paint to drag */
     ar.ar_search.r_xbot = use->cu_bbox.r_xbot - 1;
-    ar.ar_search.r_xtop = use->cu_bbox.r_xtop + TechHalo;
-    ar.ar_search.r_ybot = edge->e_ybot - TechHalo;
-    ar.ar_search.r_ytop = edge->e_ytop + TechHalo;
+    ar.ar_search.r_xtop = use->cu_bbox.r_xtop + DRCTechHalo;
+    ar.ar_search.r_ybot = edge->e_ybot - DRCTechHalo;
+    ar.ar_search.r_ytop = edge->e_ytop + DRCTechHalo;
 
     /* Shadow search area for the paint planes */
     shadowArea.r_xbot = edge->e_x - 1;
-    shadowArea.r_xtop = edge->e_newx + TechHalo;
-    shadowArea.r_ybot = edge->e_ybot - TechHalo;
-    shadowArea.r_ytop = edge->e_ytop + TechHalo;
+    shadowArea.r_xtop = edge->e_newx + DRCTechHalo;
+    shadowArea.r_ybot = edge->e_ybot - DRCTechHalo;
+    shadowArea.r_ytop = edge->e_ytop + DRCTechHalo;
 
     /* Search all the paint planes */
     for (pNum = PL_TECHDEPBASE; pNum < DBNumPlanes; pNum++)
@@ -933,13 +933,13 @@ prCell(edge)
      * We could do a shadow search, but just use area search instead
      * since we don't expect there to be too many cells in the path.
      * Cells to the left of the RHS of use get dragged by the same
-     * amount as use is moving; cells to its right stay TechHalo away
+     * amount as use is moving; cells to its right stay DRCTechHalo away
      * (or closer if they were originally closer).
      */
     cellArea.r_xbot = use->cu_bbox.r_xbot - 1;
-    cellArea.r_xtop = edge->e_newx + TechHalo;
-    cellArea.r_ybot = edge->e_ybot - TechHalo;
-    cellArea.r_ytop = edge->e_ytop + TechHalo;
+    cellArea.r_xtop = edge->e_newx + DRCTechHalo;
+    cellArea.r_ybot = edge->e_ybot - DRCTechHalo;
+    cellArea.r_ytop = edge->e_ytop + DRCTechHalo;
     (void) TiSrArea((Tile *) NULL, plowYankDef->cd_planes[edge->e_pNum],
 		&cellArea, plowFoundCell,
 		(ClientData) &ar);
@@ -951,7 +951,7 @@ prCell(edge)
  * plowCellDragPaint --
  *
  * Called by DBSrPaintArea() on behalf of prCell() above for each tile
- * overlapping the cell being moved (ar->ar_moving->e_use), or a TechHalo
+ * overlapping the cell being moved (ar->ar_moving->e_use), or a DRCTechHalo
  * wide halo around it to the right, top, or bottom.
  *
  * If the LHS of the tile lies to the right of the LHS of the cell, we
@@ -1006,8 +1006,8 @@ plowCellDragPaint(tile, ar)
  *
  * Filter procedure called by plowSrShadow() on behalf of prCell above.
  * Each paint tile in the shadow of the RHS of the cell being moved
- * gets pushed TechHalo in front of the cell when it moves.  (If the
- * paint was already closer than TechHalo to the front of the cell,
+ * gets pushed DRCTechHalo in front of the cell when it moves.  (If the
+ * paint was already closer than DRCTechHalo to the front of the cell,
  * it stays that close).
  *
  * Results:
@@ -1028,7 +1028,7 @@ plowCellPushPaint(impactedEdge, ar)
     int xsep, newx;
 
     xsep = impactedEdge->e_x - movingEdge->e_x;
-    if (xsep > TechHalo) xsep = TechHalo;
+    if (xsep > DRCTechHalo) xsep = DRCTechHalo;
 
     /* Queue the edge if it hasn't already moved far enough */
     newx = movingEdge->e_newx + xsep;
@@ -1047,7 +1047,7 @@ plowCellPushPaint(impactedEdge, ar)
  * plowFoundCell --
  *
  * Called for each cell tile found by an area enumeration of the umbra of
- * a moving edge, plus a TechHalo-wide halo above, below, and to its right.
+ * a moving edge, plus a DRCTechHalo-wide halo above, below, and to its right.
  * Determine how far each use associated with that cell tile must move.  If
  * that cell has not already moved far enough, queue it.
  *
@@ -1085,11 +1085,11 @@ plowFoundCell(cellTile, ar)
 	else
 	{
 	    /*
-	     * If pushing the cell, keep it TechHalo in front of the edge
+	     * If pushing the cell, keep it DRCTechHalo in front of the edge
 	     * unless it was already closer.
 	     */
 	    xsep = use->cu_bbox.r_xbot - movingEdge->e_x;
-	    if (xsep > TechHalo) xsep = TechHalo;
+	    if (xsep > DRCTechHalo) xsep = DRCTechHalo;
 	    xmove = movingEdge->e_newx + xsep - use->cu_bbox.r_xbot;
 	}
 
