@@ -550,10 +550,10 @@ plowTestJog(def, area)
     plowDummyUse->cu_def = def;
     scx.scx_use = plowDummyUse;
     scx.scx_trans = GeoIdentityTransform;
-    scx.scx_area.r_xbot = area->r_xbot - TechHalo;
-    scx.scx_area.r_ybot = area->r_ybot - TechHalo;
-    scx.scx_area.r_xtop = area->r_xtop + TechHalo;
-    scx.scx_area.r_ytop = area->r_ytop + TechHalo;
+    scx.scx_area.r_xbot = area->r_xbot - DRCTechHalo;
+    scx.scx_area.r_ybot = area->r_ybot - DRCTechHalo;
+    scx.scx_area.r_xtop = area->r_xtop + DRCTechHalo;
+    scx.scx_area.r_ytop = area->r_ytop + DRCTechHalo;
     (void) DBCellCopyPaint(&scx, &DBAllButSpaceAndDRCBits, 0, plowYankUse);
     DBReComputeBbox(plowYankDef);
     DBWAreaChanged(plowYankDef,&TiPlaneRect,DBW_ALLWINDOWS,&DBAllButSpaceBits);
