@@ -27,6 +27,7 @@
 #include <errno.h>
 
 #include "tcltk/tclmagic.h"
+#include "utils/main.h"   
 #include "utils/magic.h"   
 #include "utils/geometry.h"
 #include "tiles/tile.h"  
@@ -994,7 +995,7 @@ int
 Tclmagic_Init(interp)
     Tcl_Interp *interp;
 {
-    char *cadhome;
+    char *cadroot;
 
     /* Sanity check! */
     if (interp == NULL) return TCL_ERROR;
@@ -1020,14 +1021,14 @@ Tclmagic_Init(interp)
 
     Tcl_Eval(interp, "lappend auto_path " TCL_DIR );
 
-    /* Set $CAD_HOME as a Tcl variable */
+    /* Set $CAD_ROOT as a Tcl variable */
 
-    cadhome = getenv("CAD_HOME");
-    if (cadhome == NULL) cadhome = CAD_DIR;
+    cadroot = getenv("CAD_ROOT");
+    if (cadroot == NULL) cadroot = CAD_DIR;
 
-    Tcl_SetVar(interp, "CAD_HOME", cadhome, TCL_GLOBAL_ONLY);
+    Tcl_SetVar(interp, "CAD_ROOT", cadroot, TCL_GLOBAL_ONLY);
 
-    Tcl_PkgProvide(interp, "Tclmagic", "7.3");
+    Tcl_PkgProvide(interp, "Tclmagic", MAGIC_VERSION);
     return TCL_OK;
 }
 
