@@ -55,8 +55,8 @@ proc magic::promptload {type} {
 		magic::cellname create cif_temp
 		magic::load cif_temp
 		magic::cif read [file root $Layoutfilename]
-		set childcells [magic::cellname list children cif_temp]
-		magic::load [lindex $childcells 0]
+	        set childcells [magic::cellname list children cif_temp]
+	        magic::load [lindex $childcells 0]
 		magic::cellname delete cif_temp -noprompt
 		if {[llength $childcells] > 1} {
 		   puts stdout "Cells read from GDS file: $childcells"
@@ -393,6 +393,11 @@ proc magic::maketechmanager { mgrpath } {
    menubutton ${mgrpath}.extract.lstyle -text "" -foreground blue \
 	-menu ${mgrpath}.extract.lstyle.menu
 
+   frame ${mgrpath}.drc
+   label ${mgrpath}.drc.llab -text "DRC style: "
+   menubutton ${mgrpath}.drc.lstyle -text "" -foreground blue \
+	-menu ${mgrpath}.drc.lstyle.menu
+
    pack ${mgrpath}.title.tlab -side left
    pack ${mgrpath}.title.tname -side left
    pack ${mgrpath}.title.tvers -side left
@@ -412,6 +417,8 @@ proc magic::maketechmanager { mgrpath } {
    pack ${mgrpath}.cif1.llambda -side left
    pack ${mgrpath}.extract.llab -side left
    pack ${mgrpath}.extract.lstyle -side left
+   pack ${mgrpath}.drc.llab -side left
+   pack ${mgrpath}.drc.lstyle -side left
 
    pack ${mgrpath}.title -side top -fill x
    pack ${mgrpath}.subtitle -side top -fill x
@@ -428,7 +435,6 @@ proc magic::maketechmanager { mgrpath } {
 # Create or redisplay the technology manager
 
 proc magic::techmanager {{option "update"}} {
-   global tcl_precision
    global CAD_ROOT
 
    if {[catch {wm state .techmgr}]} {
@@ -442,29 +448,20 @@ proc magic::techmanager {{option "update"}} {
    }
 
    if {$option == "create"} {
-      set m [menu .techmgr.title.tname.menu -tearoff 0]
-      set dirlist [subst [magic::path sys]]
-      set tlist {}
-      foreach i $dirlist {
-	 lappend tlist [glob -nocomplain ${i}/*.tech]
-	 lappend tlist [glob -nocomplain ${i}/*.tech27]
-      }
-      foreach i [join $tlist] {
-	 set j [file tail [file rootname ${i}]]
-	 $m add command -label $j -command \
-		"magic::tech load $j ; magic::techmanager update"
-      }
-
+      menu .techmgr.title.tname.menu -tearoff 0
       menu .techmgr.cif0.lstyle.menu -tearoff 0
       menu .techmgr.cif1.lstyle.menu -tearoff 0
       menu .techmgr.extract.lstyle.menu -tearoff 0
+      menu .techmgr.drc.lstyle.menu -tearoff 0
     
    }
 
    if {$option == "init"} {
+	.techmgr.title.tname.menu delete 0 end
 	.techmgr.cif0.lstyle.menu delete 0 end
 	.techmgr.cif1.lstyle.menu delete 0 end
 	.techmgr.extract.lstyle.menu delete 0 end
+	.techmgr.drc.lstyle.menu delete 0 end
    }
 
    if {$option == "init" || $option == "create"} {
@@ -488,10 +485,28 @@ proc magic::techmanager {{option "update"}} {
 		"magic::extract style $i ; \
 		 magic::techmanager update"
       }
-   }
 
-   set psave $tcl_precision
-   set tcl_precision 3
+      set tlist [magic::drc listall style]
+      foreach i $tlist {
+	 .techmgr.drc.lstyle.menu add command -label $i -command \
+		"magic::drc style $i ; \
+		 magic::techmanager update"
+      }
+
+      set dirlist [subst [magic::path sys]]
+      set tlist {}
+      foreach i $dirlist {
+	 lappend tlist [glob -nocomplain ${i}/*.tech]
+	 lappend tlist [glob -nocomplain ${i}/*.tech27]
+      }
+      foreach i [join $tlist] {
+	 set j [file tail [file rootname ${i}]]
+	 .techmgr.title.tname.menu add command -label $j -command \
+		"magic::tech load $j ; \
+		 magic::techmanager update"
+      }
+
+   }
 
    set techlambda [magic::tech lambda]
    set tech1 [lindex $techlambda 1]
@@ -502,19 +517,20 @@ proc magic::techmanager {{option "update"}} {
    set techstuff [magic::tech version]
    .techmgr.title.tvers configure -text "(version [lindex $techstuff 0])"
    .techmgr.subtitle configure -text [lindex $techstuff 1]
-   .techmgr.lambda0.lval configure -text [expr {[magic::cif lambda output] * $tscale}]
+   set lotext [format "%g" [expr {[magic::cif lambda output] * $tscale}]]
+   .techmgr.lambda0.lval configure -text $lotext
    .techmgr.cif0.lstyle configure -text [magic::cif list istyle]
-   .techmgr.cif0.llambda configure -text [expr {[magic::cif lambda input] * $tscale}]
+   set litext [format "%g" [expr {[magic::cif lambda input] * $tscale}]]
+   .techmgr.cif0.llambda configure -text $litext
    .techmgr.cif1.lstyle configure -text [magic::cif list ostyle]
-   .techmgr.cif1.llambda configure -text [expr {[magic::cif lambda output] * $tscale}]
+   .techmgr.cif1.llambda configure -text $lotext
    .techmgr.extract.lstyle configure -text [magic::extract list style]
+   .techmgr.drc.lstyle configure -text [magic::drc list style]
 
    .techmgr.lambda1.lval0 delete 0 end
    .techmgr.lambda1.lval1 delete 0 end
    .techmgr.lambda1.lval0 insert end $tech1
    .techmgr.lambda1.lval1 insert end $tech0
-
-   set tcl_precision $psave
 }
 
 proc magic::caption {winpath {subcommand {}}} {
@@ -557,6 +573,7 @@ magic::tag findbox "magic::scrollupdate %W"
 magic::tag see "magic::toolupdate %W %1 %2"
 magic::tag tech "magic::techrebuild %W %1"
 magic::tag drc "magic::drcupdate %1"
+magic::tag path "magic::techmanager update"
 if {$MagicBLT} {
    magic::tag cellname "magic::mgrupdate %W %1"
    magic::tag select "magic::mgrselect %R"
@@ -672,11 +689,12 @@ proc magic::cursorview {win} {
       if {[expr {$dy == int($dy)}]} {set dy [expr {int($dy)}]}
       if {$dx >= 0} {set dx "+$dx"}
       if {$dy >= 0} {set dy "+$dy"}
-      ${framename}.titlebar.pos configure -text "($olstx $olsty) $dx $dy lambda"
+      set titletext [format "(%g %g) %g %g lambda" $olstx $olsty $dx $dy]
+      ${framename}.titlebar.pos configure -text $titletext
    } else {
-      ${framename}.titlebar.pos configure -text "($olstx $olsty) lambda"
+      set titletext [format "(%g %g) lambda" $olstx $olsty]
+      ${framename}.titlebar.pos configure -text $titletext
    }
-
 }
 
 proc magic::toolupdate {win {yesno "yes"} {layerlist "none"}} {
@@ -1255,9 +1273,8 @@ proc magic::openwrapper {{cell ""} {framename ""}} {
 
    magic::caption ${winname}
 
-   # Change "open" and "close" macros so they don't generate non-GUI
+   # Remove "open" and "close" macros so they don't generate non-GUI
    # windows or (worse) blow away the window inside the GUI frame
-
    if {[magic::macro list o] == "openwindow"} {
       magic::macro o "openwrapper"
    }
