@@ -215,26 +215,6 @@ extern char AbortMessage[];
 
 /* ---------------- Start of Machine Configuration Section ----------------- */
 
-
- /* ------- Configuration:  Selection of Byte Ordering -------- */
-
- /* "configure" script calls AC_C_BIGENDIAN, and should define	*/
- /* WORDS_BIGENDIAN if the machine is Big Endian.		*/
-
-/*	Big Endian:
- *		MSB....................LSB
- *		byte0  byte1  byte2  byte3
- *
- *	Little Endian:
- *		MSB....................LSB
- *		byte3  byte2  byte1  byte0
- *
- *	In big-endian, a pointer to a word points to the byte that
- *	contains the most-significant-bit of the word.  In little-endian, 
- *	it points to the byte containing the least-significant-bit.
- *
- */
-
     /* ------- Configuration:  Handle Missing Routines/Definitions ------- */
 
 /* System V is missing some BSDisms. */
