@@ -557,7 +557,7 @@ mainInitAfterArgs()
     TechAddClient("mzrouter", nullProc,nullProc,nullProc,
 			sec_types|sec_planes, &sec_mzrouter, TRUE);
 #endif
-    TechAddClient("drc", DRCTechInit, DRCTechAddRule, DRCTechFinal,
+    TechAddClient("drc", DRCTechStyleInit, DRCTechLine, DRCTechFinal,
 			sec_types|sec_planes, &sec_drc, FALSE);
     TechAddClient("drc", PlowDRCInit, PlowDRCLine, PlowDRCFinal,
 			(SectionID) 0, (SectionID *) 0, FALSE);
@@ -599,9 +599,6 @@ mainInitAfterArgs()
 			sec_types, &sec_plot, TRUE);
 #endif
 
-    /* Pre-Load initialization of the DRC module */
-    DRCPreInit();
-
     /* Load the technology file */
 
     if (!TechLoad(TechDefault, 0))
