@@ -23,7 +23,7 @@
 #ifndef	_STACK_H
 #define	_STACK_H
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 
 struct stackBody
 {
