@@ -947,7 +947,7 @@ windDoMacro(w, cmd, interactive)
 	    argstart = 2;
     }
 
-    if (cmd->tx_argc > argstart)
+    if (cmd->tx_argc >= argstart)
     {
 	if (!strcmp(cmd->tx_argv[argstart], "list"))
 	{
